
# figures for the sex task specialisation ms

# setup {{{
setwd("../work/")
source("../scripts/data_proc.R")
library(lattice)
setEPS(family="Times")
#}}}

# functions {{{
rescale.coeff <- function(b) {#{{{
  # rescale the coefficients of the benefit function so that the maximum
  # of thish function is always 1
  bb <- (b[1] + b[2])/2
  DD <- abs(b[1] - bb)
  if(b[3] > 0) {
    bb <- (2*DD + b[3])^2
    bb <- 1 + DD - 0.25*(bb/b[3])
    b[1] <- bb + DD
    b[2] <- bb - DD
  } 
  b
}#}}}
#}}}

# AN_fig-1: comparative data {{{

d <- matrix(c(0.0 , 32,0.125 , 73,0.25 , 66,0.375 , 23,0.5 , 5,0.625,
        13,0.75 , 1,0.875 , 2,1.0 , 1), byrow=TRUE, ncol=2)

postscript(file="AN_fig-1.eps")
mb <- barplot(d[,2], ylab="Number of species",
    xlab="Degree of parental role specialisation")
axis(1, at=mb, labels=d[,1])
box(bty="l")
dev.off()
#}}}

# AN_fig-3: model {{{
#pdf(file="AN_fig-3.pdf", width=10, height=7.5)
postscript(file="AN_fig-3.eps", width=10, height=7.5)
op <- par(mar=c(5,4,2,1)+0.1)
layout(matrix(1:4, ncol=2, byrow=TRUE))
## figure 1a {{{
v.vals <- c(0, 0.25, 0.5, 1)
e1 <- seq(0, 1, 0.01)
e2 <- 1 - e1
b1 <- b2 <- 1
b3 <- v.vals
plot(e1, e1, type="n", ylim=c(0.5,1), ylab="value of care", 
    xlab="effort spent on Task 1", bty="l")
for(i in 1:length(b3)) {
  b <- rescale.coeff(c(b1, b2, b3[i]))
  lines(e1, b[1]*e1 + b[2]*e2 + b[3]*e1*e2, lty=i, lwd=2)
}
legend("bottom", legend=formatC(b3, digits=2, format="f"),
    lty=1:length(b3), bty="n", lwd=2,
    title=expression(italic(B)[3]), ncol=2)
mtext("(a)", side=3, adj=0, line=1)
#}}}
## figure 1b {{{
tvc <- seq(0, 50, 0.1)
plot(tvc, exp(-0.2/(tvc/50)), type="l", bty="l", 
    xlab="total value of care", ylab="offspring's survival")
mtext("(b)", side=3, line=1, adj=0)
#}}}
# figure 1c {{{
c1 <- c2 <- 1
c3 <- v.vals
plot(e1, e1, type="n", xlab="effort spent on Task 1", bty="l",
    ylab="parent's mortality rate", ylim=c(0.08, 0.15))
for(i in 1:length(c3)) {
  lines(e1, 0.1*(c1*e1 + c2*e2 + c3[i]*e1*e2), lty=i, lwd=2)
}
legend("top", legend=formatC(c3, digits=2, format="f"), bty="n", lwd=2,
    lty=1:length(c3), title=expression(italic(C)[3]), ncol=2)
mtext("(c)", side=3, line=1, adj=0)
#}}}
# figure 1d {{{
ci <- 1
cj <- 1 + v.vals/2
c3 <- 0
plot(e1, e1, type="n", xlab="effort spent on Task 1", bty="l",
    ylab="parent's mortality rate", ylim=c(0.08, 0.15))
for(i in 1:length(cj)) { # males
  lines(e1, 0.1*(ci*e1 + cj[i]*e2 + c3*e1*e2), lty=i, lwd=2)
}
for(i in 1:length(cj)) { # females
  lines(e1, 0.1*(cj[i]*e1 + ci*e2 + c3*e1*e2), lty=i, lwd=2,
        col="grey70")
}
legend("top", legend=formatC(cj-1, digits=3, format="f"), bty="n",
    lwd=2, lty=1:length(cj), title=expression(Delta), ncol=2)
legend("bottom", legend=c("male", "female"), lwd=2, col=c("black",
                                                          "grey70"), bty="n",
    title="sex", ncol=2)
mtext("(d)", side=3, line=1, adj=0)
#}}}
layout(1)
par(op)
dev.off()
#}}}

# AN_fig-4: baseline case supplementary {{{
load("../runs/RS_asymmetric/gg.Rdata")
#pdf(file="AN_fig-4.pdf", width=10.5, height=7)
postscript(file="AN_fig-4.eps", width=10.5, height=7)
op <- par(mar=c(3,4,2,1)+0.1, oma=c(2,1,0,1)+0.1)
layout(matrix(1:6, ncol=3))
## figure a & b {{{
es <- gg$B3==1 & gg$C12==1 & gg$F_MU_I==0.2 & gg$F_MU_O==0.2 &
gg$F_k_SS==1 & gg$r_mating==0.1

f.baseline <- unique(gg$ID[es])
f.baseline <- paste("../runs/RS_asymmetric/", f.baseline, "-r1.dat.gz", sep="")
g.bl <- O.gen(f.baseline)
L.f <- tapply(1:nrow(g.bl), g.bl$gen, function(i) {
      sum(g.bl$pop.size[i] * g.bl$T1.f[i],
          na.rm=TRUE)/sum(g.bl$pop.size[i], na.rm=TRUE)
    })
L.m <- tapply(1:nrow(g.bl), g.bl$gen, function(i) {
      sum(g.bl$pop.size[i] * g.bl$T1.m[i],
          na.rm=TRUE)/sum(g.bl$pop.size[i], na.rm=TRUE)
    })
gen <- unique(g.bl$gen)
plot(L.m~gen, type="l", ylim=c(0,15), lwd=2, xaxt="n",
    xlab="", 
    ylab="", bty="l")
lines(L.f~gen, col="grey70", lty=2, lwd=2)
for(i in 0:5) {
  axis(1, at=i*1e5, labels=i)
}
#legend("top", legend=c("male", "female"), lty=1:2, col=1:2, lwd=2,
#    bty="n", title="sex", ncol=2)
mtext("(a)", side=3, line=1, adj=0)
mtext("baseline", side=3, line=-0.2, adj=0.5, cex=0.9)

A.f <- tapply(1:nrow(g.bl), g.bl$gen, function(i) {
      sum(g.bl$pop.size[i] * g.bl$T2.f[i],
          na.rm=TRUE)/sum(g.bl$pop.size[i], na.rm=TRUE)
    })
A.m <- tapply(1:nrow(g.bl), g.bl$gen, function(i) {
      sum(g.bl$pop.size[i] * g.bl$T2.m[i],
          na.rm=TRUE)/sum(g.bl$pop.size[i], na.rm=TRUE)
    })
plot(A.m~gen, type="l", ylim=c(0,1), lwd=2, xaxt="n", 
    xlab="",
    ylab="", bty="l")
lines(A.f~gen, col="grey70", lty=2, lwd=2)
for(i in 0:5) {
  axis(1, at=i*1e5, labels=i)
}
#legend("top", legend=c("male", "female"), lty=1:2, col=1:2, lwd=2,
#    bty="n", title="sex", ncol=2)
mtext("(b)", side=3, line=1, adj=0)
#}}}
## figure a & b {{{
es <- gg$B3==1 & gg$C12==1 & gg$F_MU_I==0.2 & gg$F_MU_O==0.2 &
gg$F_k_SS==5 & gg$r_mating==0.1

f.baseline <- unique(gg$ID[es])
f.baseline <- paste("../runs/RS_asymmetric/", f.baseline, "-r3.dat.gz", sep="")
g.bl <- O.gen(f.baseline)
L.f <- tapply(1:nrow(g.bl), g.bl$gen, function(i) {
      sum(g.bl$pop.size[i] * g.bl$T1.f[i],
          na.rm=TRUE)/sum(g.bl$pop.size[i], na.rm=TRUE)
    })
L.m <- tapply(1:nrow(g.bl), g.bl$gen, function(i) {
      sum(g.bl$pop.size[i] * g.bl$T1.m[i],
          na.rm=TRUE)/sum(g.bl$pop.size[i], na.rm=TRUE)
    })
gen <- unique(g.bl$gen)
# sexes swapped to follow convention: mothers care, fathers are lazy
plot(L.f~gen, type="l", ylim=c(0,15), lwd=2, xaxt="n",     xlab="",
    ylab="", bty="l")
lines(L.m~gen, col="grey70", lty=2, lwd=2)
for(i in 0:5) {
  axis(1, at=i*1e5, labels=i)
}
#legend("top", legend=c("male", "female"), lty=1:2, col=1:2, lwd=2,
#    bty="n", title="sex", ncol=2)
mtext("(c)", side=3, line=1, adj=0)
mtext("sexual selection on males", side=3, line=-0.2, adj=0.5, cex=0.9)

A.f <- tapply(1:nrow(g.bl), g.bl$gen, function(i) {
      sum(g.bl$pop.size[i] * g.bl$T2.f[i],
          na.rm=TRUE)/sum(g.bl$pop.size[i], na.rm=TRUE)
    })
A.m <- tapply(1:nrow(g.bl), g.bl$gen, function(i) {
      sum(g.bl$pop.size[i] * g.bl$T2.m[i],
          na.rm=TRUE)/sum(g.bl$pop.size[i], na.rm=TRUE)
    })
plot(A.f~gen, type="l", ylim=c(0,1), lwd=2, xaxt="n",
    xlab="",
    ylab="", bty="l")
lines(A.m~gen, col="grey70", lty=2, lwd=2)
for(i in 0:5) {
  axis(1, at=i*1e5, labels=i)
}
#legend("top", legend=c("male", "female"), lty=1:2, col=1:2, lwd=2,
#    bty="n", title="sex", ncol=2)
mtext("(d)", side=3, line=1, adj=0)
#}}}
## figure c & d {{{
load("../runs/RS_asymmetric/gg.Rdata")
es <- gg$B3==1 & gg$C12==2 & gg$F_MU_I==0.2 & gg$F_MU_O==0.2 &
gg$F_k_SS==5 & gg$r_mating==0.1

f.baseline <- unique(gg$ID[es])
f.baseline <- paste("../runs/RS_asymmetric/", f.baseline, "-r0.dat.gz", sep="")
g.bl <- O.gen(f.baseline)
L.f <- tapply(1:nrow(g.bl), g.bl$gen, function(i) {
      sum(g.bl$pop.size[i] * g.bl$T1.f[i],
          na.rm=TRUE)/sum(g.bl$pop.size[i], na.rm=TRUE)
    })
L.m <- tapply(1:nrow(g.bl), g.bl$gen, function(i) {
      sum(g.bl$pop.size[i] * g.bl$T1.m[i],
          na.rm=TRUE)/sum(g.bl$pop.size[i], na.rm=TRUE)
    })
gen <- unique(g.bl$gen)
# sexes swapped to follow convention: mothers care, fathers are lazy
plot(L.f~gen, type="l", ylim=c(0,15), lwd=2, xaxt="n",     xlab="",
    ylab="", bty="l")
lines(L.m~gen, col="grey70", lty=2, lwd=2)
for(i in 0:5) {
  axis(1, at=i*1e5, labels=i)
}
#legend("top", legend=c("male", "female"), lty=1:2, col=1:2, lwd=2,
#    bty="n", title="sex", ncol=2)
mtext("(e)", side=3, line=1, adj=0)
mtext("sexual selection on males +
skill differences", side=3, line=-1,
    adj=0.5, cex=0.9)

A.f <- tapply(1:nrow(g.bl), g.bl$gen, function(i) {
      sum(g.bl$pop.size[i] * g.bl$T2.f[i],
          na.rm=TRUE)/sum(g.bl$pop.size[i], na.rm=TRUE)
    })
A.m <- tapply(1:nrow(g.bl), g.bl$gen, function(i) {
      sum(g.bl$pop.size[i] * g.bl$T2.m[i],
          na.rm=TRUE)/sum(g.bl$pop.size[i], na.rm=TRUE)
    })
plot(A.f~gen, type="l", ylim=c(0,1), lwd=2, xaxt="n",
    xlab="", col="grey70", lty=2,
    ylab="", bty="l")
lines(A.m~gen, col=1, lty=1, lwd=2)
for(i in 0:5) {
  axis(1, at=i*1e5, labels=i)
}
legend("center", legend=c("male", "female"), lty=1:2, col=c("black",
                                                            "grey70"), lwd=2,
    bty="n", title="sex", ncol=2)
mtext("(f)", side=3, line=1, adj=0)
#}}}
#mtext("generation", side=1, outer=TRUE, adj=0.525, line=0)
mtext(expression(paste("generation (", phantom(.) %*% 10^5, ")")),
    side=1, outer=TRUE, adj=0.525, line=0)
#mtext(expression(paste("length of care, ", italic(L)[s])), side=2,
#    outer=TRUE, adj=0.8, line=-0.5)
#mtext(expression(paste("proportion of care on Task 1, ",
#            italic(A)[s])), side=2, outer=TRUE, adj=0.15, line=-0.5)
mtext("length of care", side=2, outer=TRUE, adj=0.8, line=-0.5)
mtext("proportion of care on Task 1", side=2, outer=TRUE, adj=0.15,
    line=-0.5)
layout(1)
par(op)
dev.off()
#}}}

# AN_fig-5: systemetic variation of Delta and B3 and C3 and B3 {{{
gg.file <- "../runs/a-F_k_SS/gg.Rdata"
load(gg.file)

es <- gg$F_k_SS == 5
ggs <- gg[es,]

#pdf(file="AN_fig-5.pdf", width=9, height=9)
postscript(file="AN_fig-5.eps", width=9, height=9)
op <- par(mar=c(3,4,1.5,1)+0.1, oma=c(1,1,0,0)+0.1)
layout(matrix(1:4, ncol=2))
plot(role.spec~B3, ggs, type="n", bty="l", ylim=c(0,1),
    xlab="", ylab="")
leg <- list()
lty <- list()
colour <- list()
pch <- list()
x <- b3 <- sort(unique(ggs$B3))
c3 <- sort(unique(ggs$C12))
c3 <- c3[-length(c3)]
i <- 1
for(j in 1:length(c3)) {
  es <- ggs$C12 == c3[j]
  y <- tapply((ggs$role.spec[es]), ggs$B3[es], median)
  y.iqr <- matrix(unlist(tapply((ggs$role.spec[es]), ggs$B3[es],
              quantile, probs=c(0.25, 0.75))), ncol=2, byrow=TRUE)
  lines(x, y, col=1, lty=j, lwd=1)
  points(x, y, col=1, pch=15+j)
  #segments(x, y+y.sd, x, y-y.sd, col=1, lty=i)
  arrows(x, y.iqr[,1], x, y.iqr[,2], col=1, lty=j, length=0.05,
      angle=90, code=3)
  leg[[paste(i,j)]] <- formatC(c3[j]-1, digits=2, format="f")
  lty[[paste(i,j)]] <- j
  colour[[paste(i,j)]] <- j
  pch[[paste(i,j)]] <- 15+j
}
#legend("center", legend=leg, lty=unlist(lty), col=unlist(colour),
#    bty="n", pch=unlist(pch), ncol=2, 
#    title=expression(paste("skill difference, ",Delta)))
mtext("(a)", side=3, line=0.5, adj=0)
plot(div.labour~B3, ggs, type="n", bty="l", #ylim=c(0,0.6),
    xlab="", ylab="")
mtext("uniparental care", side=2, adj=0, line=2, cex=0.75)
mtext("biparental care", side=2, adj=1, line=2, cex=0.75)
#abline(h=0.5, lty=2, col="grey")
leg <- list()
lty <- list()
colour <- list()
pch <- list()
x <- b3 <- sort(unique(ggs$B3))
c3 <- sort(unique(ggs$C12))
c3 <- c3[-length(c3)]
i <- 1
for(j in 1:length(c3)) {
  es <- ggs$C12 == c3[j]
  y <- tapply(ggs$div.labour[es], ggs$B3[es], median)
  y.iqr <- matrix(unlist(tapply(ggs$div.labour[es], ggs$B3[es],
              quantile, probs=c(0.25, 0.75))), ncol=2, byrow=TRUE)
  lines(x, y, col=1, lty=j, lwd=1)
  points(x, y, col=1, pch=15+j)
  #segments(x, y+y.sd, x, y-y.sd, col=1, lty=i)
  arrows(x, y.iqr[,1], x, y.iqr[,2], col=1, lty=j, length=0.05,
      angle=90, code=3)
  leg[[paste(i,j)]] <- formatC(c3[j]-1, digits=3, format="f")
  lty[[paste(i,j)]] <- j
  colour[[paste(i,j)]] <- j
  pch[[paste(i,j)]] <- 15+j
}
legend("right", legend=leg, lty=unlist(lty), col="black", #col=unlist(colour),
    bty="n", pch=unlist(pch), ncol=2, 
    title=expression(paste("skill difference, ",Delta)))
mtext("(c)", side=3, line=0.5, adj=0)
#mtext(expression(paste("interactive benefit, ",
#italic(B)[3])), side=1, outer=TRUE, adj=0.5, line=0)
#layout(1)
#par(op)
#dev.off()
gg.file <- "../runs/F_k_SS/gg.Rdata"
load(gg.file)

es <- gg$F_k_SS == 5
ggs <- gg[es,]

#pdf(file="fig-BC.pdf", width=9, height=4.5)
#op <- par(mar=c(3,4,1.5,1)+0.1, oma=c(1,0,0,0)+0.1)
#layout(matrix(1:2, ncol=2))
plot(role.spec~B3, ggs, type="n", bty="l", ylim=c(0,1),
    xlab="", ylab="")
leg <- list()
lty <- list()
colour <- list()
pch <- list()
x <- b3 <- sort(unique(ggs$B3))
c3 <- sort(unique(ggs$C3))
i <- 1
for(j in 1:length(c3)) {
  es <- ggs$C3 == c3[j]
  y <- tapply((ggs$role.spec[es]), ggs$B3[es], median)
  y.iqr <- matrix(unlist(tapply((ggs$role.spec[es]), ggs$B3[es],
              quantile, probs=c(0.25, 0.75))), ncol=2, byrow=TRUE)
  lines(x, y, col=1, lty=j, lwd=1)
  points(x, y, col=1, pch=15+j)
  #segments(x, y+y.sd, x, y-y.sd, col=1, lty=i)
  arrows(x, y.iqr[,1], x, y.iqr[,2], col=1, lty=j, length=0.05,
      angle=90, code=3)
  leg[[paste(i,j)]] <- formatC(c3[j], digits=2, format="f")
  lty[[paste(i,j)]] <- j
  colour[[paste(i,j)]] <- j
  pch[[paste(i,j)]] <- 15+j
}
legend("center", legend=leg, lty=unlist(lty), col="black", #col=unlist(colour),
    bty="n", pch=unlist(pch), ncol=2, 
    title=expression(paste("synergistic cost, ",italic(C)[3])))
mtext("(b)", side=3, line=0.5, adj=0)
plot(div.labour~B3, ggs, type="n", bty="l", #ylim=c(0,0.6),
    xlab="", ylab="")
mtext("uniparental care", side=2, adj=0, line=2, cex=0.75)
mtext("biparental care", side=2, adj=1, line=2, cex=0.75)
leg <- list()
lty <- list()
colour <- list()
pch <- list()
x <- b3 <- sort(unique(ggs$B3))
c3 <- sort(unique(ggs$C3))
i <- 1
for(j in 1:length(c3)) {
  es <- ggs$C3 == c3[j]
  y <- tapply(ggs$div.labour[es], ggs$B3[es], median)
  y.iqr <- matrix(unlist(tapply(ggs$div.labour[es], ggs$B3[es],
              quantile, probs=c(0.25, 0.75))), ncol=2, byrow=TRUE)
  lines(x, y, col=1, lty=j, lwd=1)
  points(x, y, col=1, pch=15+j)
  #segments(x, y+y.sd, x, y-y.sd, col=1, lty=i)
  arrows(x, y.iqr[,1], x, y.iqr[,2], col=1, lty=j, length=0.05,
      angle=90, code=3)
  leg[[paste(i,j)]] <- formatC(c3[j], digits=2, format="f")
  lty[[paste(i,j)]] <- j
  colour[[paste(i,j)]] <- j
  pch[[paste(i,j)]] <- 15+j
}
#legend("right", legend=leg, lty=unlist(lty), col=unlist(colour),
#    bty="n", pch=unlist(pch), ncol=2, 
#    title=expression(paste("synergistic cost, ",italic(C)[3])))
mtext("(d)", side=3, line=0.5, adj=0)
mtext(expression(paste("synergistic benefit, ",
            italic(B)[3])), side=1, outer=TRUE, adj=0.5, line=0)
mtext("division of labour", side=2, outer=TRUE, adj=0.225,
    line=0)
mtext("level of task specialisation", side=2, outer=TRUE, adj=0.835,
    line=0)
layout(1)
par(op)
dev.off()

#}}}

# AN_fig-6: division of labour {{{
#pdf(file="AN_fig-6.pdf", width=8, height=11)
postscript(file="AN_fig-6.eps", width=8, height=11)
layout(matrix(1:6, byrow=TRUE, ncol=2))
# effect of mating rate {{{
## symmetric case {{{
load("../runs/RS_symmetric/gg.Rdata")
#apply(gg[bl.es,17:22], 2, table)

bl.es <- gg$F_MU_I == 0.2 & gg$F_MU_O == 0.2 & gg$F_k_SS == 5
plot(male.care~r_mating, gg, subset=bl.es, ylim=c(0,1), type="n",
     xlab=expression(paste("mating rate, ", r[mating])), bty="l",
     ylab="proportion of female care")
sp.es <- gg$B3 == 0 & gg$C3 == 0
x <- sort(unique(gg$r_mating))
y <- tapply((1-gg$male.care[sp.es & bl.es]), gg$r_mating[sp.es & bl.es], median)
y.iqr <- matrix(unlist(tapply((1-gg$male.care[sp.es & bl.es]),
                              gg$r_mating[sp.es & bl.es], quantile,
                              probs=c(0.25, 0.75))), ncol=2, byrow=TRUE)
lines(x, 1-y, col=1, lty=1, lwd=1)
points(x, 1-y, col=1, pch=1)
arrows(x, 1-y.iqr[,1], x, 1-y.iqr[,2], col=1, lty=1, length=0.05,
       angle=90, code=3)

sp.es <- gg$B3 == 1 & gg$C3 == 1
x <- sort(unique(gg$r_mating))
y <- tapply((1-gg$male.care[sp.es & bl.es]), gg$r_mating[sp.es & bl.es], median)
y.iqr <- matrix(unlist(tapply((1-gg$male.care[sp.es & bl.es]),
                              gg$r_mating[sp.es & bl.es], quantile,
                              probs=c(0.25, 0.75))), ncol=2, byrow=TRUE)
lines(x, 1-y, lty=2, lwd=1, col=1)
points(x, 1-y, col=1, pch=17)
arrows(x, 1-y.iqr[,1], x, 1-y.iqr[,2], col=1, lty=2, length=0.05,
       angle=90, code=3)
leg <- expression(paste(italic(C)[3] == 0, ", ", italic(B)[3] == 0, "  "),
                  paste(italic(C)[3] == 1, ", ", italic(B)[3] == 1))
legend("bottom", legend=leg, lty=1:2, col=1,
    bty="n", pch=c(1, 17), ncol=2)
mtext("(a)", side=3, line=1, adj=0)
#}}}
## asymmetric case {{{
load("../runs/RS_asymmetric/gg.Rdata")
apply(gg[,17:22], 2, table)

bl.es <- gg$F_MU_I == 0.2 & gg$F_MU_O == 0.2 & gg$F_k_SS == 5
plot(male.care~r_mating, gg, subset=bl.es, ylim=c(0,1), type="n",
     xlab=expression(paste("mating rate, ", r[mating])), bty="l",
     ylab="proportion of female care")
sp.es <- gg$B3 == 0 & gg$C12 == 1
x <- sort(unique(gg$r_mating))
y <- tapply((1-gg$male.care[sp.es & bl.es]), gg$r_mating[sp.es & bl.es], median)
y.iqr <- matrix(unlist(tapply((1-gg$male.care[sp.es & bl.es]),
                              gg$r_mating[sp.es & bl.es], quantile,
                              probs=c(0.25, 0.75))), ncol=2, byrow=TRUE)
lines(x, 1-y, col=1, lty=1, lwd=1)
points(x, 1-y, col=1, pch=1)
arrows(x, 1-y.iqr[,1], x, 1-y.iqr[,2], col=1, lty=1, length=0.05,
       angle=90, code=3)

sp.es <- gg$B3 == 1 & gg$C12 == 2
x <- sort(unique(gg$r_mating))
y <- tapply((1-gg$male.care[sp.es & bl.es]), gg$r_mating[sp.es & bl.es], median)
y.iqr <- matrix(unlist(tapply((1-gg$male.care[sp.es & bl.es]),
                              gg$r_mating[sp.es & bl.es], quantile,
                              probs=c(0.25, 0.75))), ncol=2, byrow=TRUE)
lines(x, 1-y, lty=2, lwd=1, col=1)
points(x, 1-y, col=1, pch=17)
arrows(x, 1-y.iqr[,1], x, 1-y.iqr[,2], col=1, lty=2, length=0.05,
       angle=90, code=3)
leg <- expression(paste(Delta == 0, ", ", italic(B)[3] == 0, "  "),
                  paste(Delta == 1, ", ", italic(B)[3] == 1))
legend("bottom", legend=leg, lty=1:2, col=1,
    bty="n", pch=c(1, 17), ncol=2)
mtext("(b)", side=3, line=1, adj=0)
#}}}
#}}}

# effect of single female mortality {{{
## symmetric case {{{
load("../runs/RS_symmetric/gg.Rdata")
apply(gg[,17:22], 2, table)

bl.es <- gg$F_MU_O == 0.2 & gg$F_k_SS == 5 & gg$r_mating == 0.1
plot(male.care~F_MU_I, gg, subset=bl.es, ylim=c(0,1), type="n",
     xlab=expression(paste("mortality of single females, ", M["S,f"])),
     bty="l", ylab="proportion of female care")
sp.es <- gg$B3 == 0 & gg$C3 == 0
x <- sort(unique(gg$F_MU_I))
y <- tapply((1-gg$male.care[sp.es & bl.es]), gg$F_MU_I[sp.es & bl.es], median)
y.iqr <- matrix(unlist(tapply((1-gg$male.care[sp.es & bl.es]),
                              gg$F_MU_I[sp.es & bl.es], quantile,
                              probs=c(0.25, 0.75))), ncol=2, byrow=TRUE)
lines(x, 1-y, col=1, lty=1, lwd=1)
points(x, 1-y, col=1, pch=1)
arrows(x, 1-y.iqr[,1], x, 1-y.iqr[,2], col=1, lty=1, length=0.05,
       angle=90, code=3)

sp.es <- gg$B3 == 1 & gg$C3 == 1
x <- sort(unique(gg$F_MU_I))
y <- tapply((1-gg$male.care[sp.es & bl.es]), gg$F_MU_I[sp.es & bl.es], median)
y.iqr <- matrix(unlist(tapply((1-gg$male.care[sp.es & bl.es]),
                              gg$F_MU_I[sp.es & bl.es], quantile,
                              probs=c(0.25, 0.75))), ncol=2, byrow=TRUE)
lines(x, 1-y, lty=2, lwd=1, col=1)
points(x, 1-y, col=1, pch=17)
arrows(x, 1-y.iqr[,1], x, 1-y.iqr[,2], col=1, lty=2, length=0.05,
       angle=90, code=3)
leg <- expression(paste(italic(C)[3] == 0, ", ", italic(B)[3] == 0, "  "),
                  paste(italic(C)[3] == 1, ", ", italic(B)[3] == 1))
legend("bottom", legend=leg, lty=1:2, col=1,
    bty="n", pch=c(1, 17), ncol=2)
mtext("(c)", side=3, line=1, adj=0)
#}}}
## asymmetric case {{{
load("../runs/RS_asymmetric/gg.Rdata")
apply(gg[,17:22], 2, table)

bl.es <- gg$F_MU_O == 0.2 & gg$F_k_SS == 5 & gg$r_mating == 0.1
plot(male.care~F_MU_I, gg, subset=bl.es, ylim=c(0,1), type="n",
     xlab=expression(paste("mortality of single females, ", M["S,f"])),
     bty="l", ylab="proportion of female care")
sp.es <- gg$B3 == 0 & gg$C12 == 1
x <- sort(unique(gg$F_MU_I))
y <- tapply((1-gg$male.care[sp.es & bl.es]), gg$F_MU_I[sp.es & bl.es], median)
y.iqr <- matrix(unlist(tapply((1-gg$male.care[sp.es & bl.es]),
                              gg$F_MU_I[sp.es & bl.es], quantile,
                              probs=c(0.25, 0.75))), ncol=2, byrow=TRUE)
lines(x, 1-y, col=1, lty=1, lwd=1)
points(x, 1-y, col=1, pch=1)
arrows(x, 1-y.iqr[,1], x, 1-y.iqr[,2], col=1, lty=1, length=0.05,
       angle=90, code=3)

sp.es <- gg$B3 == 1 & gg$C12 == 2
x <- sort(unique(gg$F_MU_I))
y <- tapply((1-gg$male.care[sp.es & bl.es]), gg$F_MU_I[sp.es & bl.es], median)
y.iqr <- matrix(unlist(tapply((1-gg$male.care[sp.es & bl.es]),
                              gg$F_MU_I[sp.es & bl.es], quantile,
                              probs=c(0.25, 0.75))), ncol=2, byrow=TRUE)
lines(x, 1-y, lty=2, lwd=1, col=1)
points(x, 1-y, col=1, pch=17)
arrows(x, 1-y.iqr[,1], x, 1-y.iqr[,2], col=1, lty=2, length=0.05,
       angle=90, code=3)
leg <- expression(paste(Delta == 0, ", ", italic(B)[3] == 0, "  "),
                  paste(Delta == 1, ", ", italic(B)[3] == 1))
legend("bottom", legend=leg, lty=1:2, col=1,
    bty="n", pch=c(1, 17), ncol=2)
mtext("(d)", side=3, line=1, adj=0)
#}}}
#}}}

# effect of mating rate {{{
load("../runs/mortality/gg.Rdata")
bl.es <- gg$F_MU_I == 0.2 & gg$F_MU_O == 0.2 & gg$F_k_SS == 5 &
gg$r_mating == 0.1

ggm <- gg[bl.es,]
apply(ggm[,17:24], 2, table)

## symmetric case {{{
load("../runs/RS_symmetric/gg.Rdata")

bl.es <- gg$F_MU_I == 0.2 & gg$F_MU_O == 0.2 & gg$F_k_SS == 5 &
gg$r_mating == 0.1
g <- gg[bl.es,]
apply(g[,17:22], 2, table)
n <- names(g)
n[18] <- "C12"
names(g) <- n
g$Delta <- 0
g$mort <- 0.1

gg <- rbind(ggm[ggm$Delta == 0,], g)

plot(male.care~mort, gg, ylim=c(0,1), type="n",
     xlab=expression(paste("background mortality, ", M[b])),
     bty="l", ylab="proportion of female care")
sp.es <- gg$B3 == 0 & gg$C12 == 0
x <- sort(unique(gg$mort))
y <- tapply((1-gg$male.care[sp.es]), gg$mort[sp.es], median)
y.iqr <- matrix(unlist(tapply((1-gg$male.care[sp.es]),
                              gg$mort[sp.es], quantile,
                              probs=c(0.25, 0.75))), ncol=2, byrow=TRUE)
lines(x, 1-y, col=1, lty=1, lwd=1)
points(x, 1-y, col=1, pch=1)
arrows(x, 1-y.iqr[,1], x, 1-y.iqr[,2], col=1, lty=1, length=0.05,
       angle=90, code=3)

sp.es <- gg$B3 == 1 & gg$C12 == 1
x <- sort(unique(gg$mort))
y <- tapply((1-gg$male.care[sp.es]), gg$mort[sp.es], median)
y.iqr <- matrix(unlist(tapply((1-gg$male.care[sp.es]),
                              gg$mort[sp.es], quantile,
                              probs=c(0.25, 0.75))), ncol=2, byrow=TRUE)
lines(x, 1-y, lty=2, lwd=1, col=1)
points(x, 1-y, col=1, pch=17)
arrows(x, 1-y.iqr[,1], x, 1-y.iqr[,2], col=1, lty=2, length=0.05,
       angle=90, code=3)
leg <- expression(paste(italic(C)[3] == 0, ", ", italic(B)[3] == 0, "  "),
                  paste(italic(C)[3] == 1, ", ", italic(B)[3] == 1))
legend("bottom", legend=leg, lty=1:2, col=1,
    bty="n", pch=c(1, 17), ncol=2)
mtext("(e)", side=3, line=1, adj=0)
#}}}
## asymmetric case {{{
load("../runs/RS_asymmetric/gg.Rdata")

bl.es <- gg$F_MU_I == 0.2 & gg$F_MU_O == 0.2 & gg$F_k_SS == 5 &
gg$r_mating == 0.1
g <- gg[bl.es,]
apply(g[,17:22], 2, table)
n <- names(g)
n[18] <- "C12"
names(g) <- n
g$Delta <- 1
g$mort <- 0.1

gg <- rbind(ggm[ggm$Delta == 1,], g)

plot(male.care~mort, gg, ylim=c(0,1), type="n",
     xlab=expression(paste("background mortality, ", M[b])),
     bty="l", ylab="proportion of female care")
sp.es <- gg$B3 == 0 & gg$C12 == 1
x <- sort(unique(gg$mort))
y <- tapply((1-gg$male.care[sp.es]), gg$mort[sp.es], median)
y.iqr <- matrix(unlist(tapply((1-gg$male.care[sp.es]),
                              gg$mort[sp.es], quantile,
                              probs=c(0.25, 0.75))), ncol=2, byrow=TRUE)
lines(x, 1-y, col=1, lty=1, lwd=1)
points(x, 1-y, col=1, pch=1)
arrows(x, 1-y.iqr[,1], x, 1-y.iqr[,2], col=1, lty=1, length=0.05,
       angle=90, code=3)

sp.es <- gg$B3 == 1 & gg$C12 == 2
x <- sort(unique(gg$mort))
y <- tapply((1-gg$male.care[sp.es]), gg$mort[sp.es], median)
y.iqr <- matrix(unlist(tapply((1-gg$male.care[sp.es]),
                              gg$mort[sp.es], quantile,
                              probs=c(0.25, 0.75))), ncol=2, byrow=TRUE)
lines(x, 1-y, lty=2, lwd=1, col=1)
points(x, 1-y, col=1, pch=17)
arrows(x, 1-y.iqr[,1], x, 1-y.iqr[,2], col=2, lty=2, length=0.05,
       angle=90, code=3)
leg <- expression(paste(Delta == 0, ", ", italic(B)[3] == 0, "  "),
                  paste(Delta == 1, ", ", italic(B)[3] == 1))
legend("bottom", legend=leg, lty=1:2, col=1,
    bty="n", pch=c(1, 17), ncol=2)
mtext("(f)", side=3, line=1, adj=0)
#}}}
#}}}
layout(1)
dev.off()
#}}}

# figure-2: baseline case {{{
load("../runs/RS_asymmetric/gg.Rdata")
pdf(file="figure-2.pdf", width=7, height=7)
op <- par(mar=c(3,4,2,1)+0.1, oma=c(2,1,0,1)+0.1)
layout(matrix(1:4, ncol=2))
## figure a & b {{{
es <- gg$B3==0 & gg$C12==1 & gg$F_MU_I==0.2 & gg$F_MU_O==0.2 &
gg$F_k_SS==5 & gg$r_mating==0.1

f.baseline <- unique(gg$ID[es])
f.baseline <- paste("../runs/RS_asymmetric/", f.baseline, "-r6.dat.gz", sep="")
g.bl <- O.gen(f.baseline)
L.f <- tapply(1:nrow(g.bl), g.bl$gen, function(i) {
      sum(g.bl$pop.size[i] * g.bl$T1.f[i],
          na.rm=TRUE)/sum(g.bl$pop.size[i], na.rm=TRUE)
    })
L.m <- tapply(1:nrow(g.bl), g.bl$gen, function(i) {
      sum(g.bl$pop.size[i] * g.bl$T1.m[i],
          na.rm=TRUE)/sum(g.bl$pop.size[i], na.rm=TRUE)
    })
gen <- unique(g.bl$gen)
# sexes swapped to follow convention: mothers care, fathers are lazy
plot(L.f~gen, type="l", ylim=c(0,15), lwd=2, xaxt="n",     xlab="",
    ylab="", bty="l")
lines(L.m~gen, col=2, lty=2, lwd=2)
for(i in 0:5) {
  axis(1, at=i*1e5, labels=i)
}
#legend("top", legend=c("male", "female"), lty=1:2, col=1:2, lwd=2,
#    bty="n", title="sex", ncol=2)
mtext("(a)", side=3, line=1, adj=0)
mtext("sexual selection on males", side=3, line=-0.2, adj=0.5, cex=0.9)

A.f <- tapply(1:nrow(g.bl), g.bl$gen, function(i) {
      sum(g.bl$pop.size[i] * g.bl$T2.f[i],
          na.rm=TRUE)/sum(g.bl$pop.size[i], na.rm=TRUE)
    })
A.m <- tapply(1:nrow(g.bl), g.bl$gen, function(i) {
      sum(g.bl$pop.size[i] * g.bl$T2.m[i],
          na.rm=TRUE)/sum(g.bl$pop.size[i], na.rm=TRUE)
    })
plot(A.f~gen, type="l", ylim=c(0,1), lwd=2, xaxt="n",
    xlab="",
    ylab="", bty="l")
lines(A.m~gen, col=2, lty=2, lwd=2)
for(i in 0:5) {
  axis(1, at=i*1e5, labels=i)
}
#legend("top", legend=c("male", "female"), lty=1:2, col=1:2, lwd=2,
#    bty="n", title="sex", ncol=2)
mtext("(b)", side=3, line=1, adj=0)
#}}}
## figure c & d {{{
load("../runs/RS_symmetric/gg.Rdata")
es <- gg$B3==1 & gg$C3==1 & gg$F_MU_I==0.2 & gg$F_MU_O==0.2 &
gg$F_k_SS==5 & gg$r_mating==0.1

f.baseline <- unique(gg$ID[es])
f.baseline <- paste("../runs/RS_symmetric/", f.baseline, "-r0.dat.gz", sep="")
g.bl <- O.gen(f.baseline)
L.f <- tapply(1:nrow(g.bl), g.bl$gen, function(i) {
      sum(g.bl$pop.size[i] * g.bl$T1.f[i],
          na.rm=TRUE)/sum(g.bl$pop.size[i], na.rm=TRUE)
    })
L.m <- tapply(1:nrow(g.bl), g.bl$gen, function(i) {
      sum(g.bl$pop.size[i] * g.bl$T1.m[i],
          na.rm=TRUE)/sum(g.bl$pop.size[i], na.rm=TRUE)
    })
gen <- unique(g.bl$gen)
# sexes swapped to follow convention: mothers care, fathers are lazy
plot(L.f~gen, type="l", ylim=c(0,15), lwd=2, xaxt="n",     xlab="",
    ylab="", bty="l")
lines(L.m~gen, col=2, lty=2, lwd=2)
for(i in 0:5) {
  axis(1, at=i*1e5, labels=i)
}
#legend("top", legend=c("male", "female"), lty=1:2, col=1:2, lwd=2,
#    bty="n", title="sex", ncol=2)
mtext("(c)", side=3, line=1, adj=0)
mtext("sexual selection +
synergistic costs and benefits", side=3, line=-0.2, adj=0.5,
    cex=0.9)

A.f <- tapply(1:nrow(g.bl), g.bl$gen, function(i) {
      sum(g.bl$pop.size[i] * g.bl$T2.f[i],
          na.rm=TRUE)/sum(g.bl$pop.size[i], na.rm=TRUE)
    })
A.m <- tapply(1:nrow(g.bl), g.bl$gen, function(i) {
      sum(g.bl$pop.size[i] * g.bl$T2.m[i],
          na.rm=TRUE)/sum(g.bl$pop.size[i], na.rm=TRUE)
    })
plot(A.f~gen, type="l", ylim=c(0,1), lwd=2, xaxt="n",
    xlab="",
    ylab="", bty="l")
lines(A.m~gen, col=2, lty=2, lwd=2)
for(i in 0:5) {
  #axis(1, at=i*1e5, labels=substitute(i %*% 10^5, list(i=i)))
  axis(1, at=i*1e5, labels=i)
}
legend("center", legend=c("male", "female"), lty=1:2, col=1:2, lwd=2,
    bty="n", title="sex", ncol=2)
mtext("(d)", side=3, line=1, adj=0)
#}}}
mtext(expression(paste("generation (", phantom(.) %*% 10^5, ")")),
    side=1, outer=TRUE, adj=0.525, line=0)
#mtext(expression(paste("length of care, ", italic(L)[s])), side=2,
#    outer=TRUE, adj=0.8, line=-0.5)
#mtext(expression(paste("proportion of care on Task 1, ",
#            italic(A)[s])), side=2, outer=TRUE, adj=0.15, line=-0.5)
mtext("length of care", side=2, outer=TRUE, adj=0.8, line=-0.5)
mtext("proportion of care on Task 1", side=2, outer=TRUE, adj=0.15,
    line=-0.5)
layout(1)
par(op)
dev.off()
#}}}

# AN_fig-7: effect of sexual selection {{{
#pdf(file="AN_fig-7.pdf", width=10, height=10)
postscript(file="AN_fig-7.eps", width=10, height=10)
op <- par(mar=c(5,4,2,1)+0.1)
layout(matrix(1:4, ncol=2, byrow=TRUE))
# figure: effect of k; asymmetric case {{{
gg.file <- "../runs/a-F_k_SS/gg.Rdata"
load(gg.file)

#es <- (gg$C12 == 1 | gg$C12 == 2) & (gg$B3 == 0 | gg$B3 == 1)
es <- (gg$C12 == 1 | gg$C12 == 1.5) & (gg$B3 == 0 | gg$B3 == 1)
ggs <- gg[es,]

es <- ggs$F_k_SS == round(ggs$F_k_SS, 0)
ggs <- ggs[es,]

#pdf(file="fig-a-F_k_SS-male_care.pdf", width=7, height=5.5)
plot(I(1-male.care)~F_k_SS, ggs, type="n", bty="l", ylim=c(0,0.6),
    xlab=expression(paste("strength of sexual selection on males, ",
            italic(k[m]))),
    ylab="proportion of male care")
abline(h=0.5, lty=2, col="grey")
abline(v=1, lty=2, col="grey")
leg <- vector()
lty <- list()
colour <- list()
pch <- list()
x <- sort(unique(ggs$F_k_SS))
b3 <- sort(unique(ggs$B3))
c3 <- sort(unique(ggs$C12))
for(i in 1:length(b3)) {
  for(j in 1:length(c3)) {
    es <- ggs$B3 == b3[i] & ggs$C12 == c3[j]
    y <- tapply((1-ggs$male.care[es]), ggs$F_k_SS[es], median)
    #y.sd <- tapply(ggs$male.care[es], ggs$F_MU_O[es], sd)
    y.iqr <- matrix(unlist(tapply((1-ggs$male.care[es]), ggs$F_k_SS[es],
                quantile, probs=c(0.25, 0.75))), ncol=2, byrow=TRUE)
    lines(x, y, col=1, lty=3-i, lwd=1)
    points(x, y, col=1, pch=(i-1)*15+j)
    #segments(x, y+y.sd, x, y-y.sd, col=1, lty=i)
    arrows(x, y.iqr[,1], x, y.iqr[,2], col=1, lty=3-i, length=0.05,
        angle=90, code=3)
    #leg[paste(i,j)] <- expression(paste("C12=", c3[j], "B3=", b3[i])
    lty[[paste(i,j)]] <- 3-i
    colour[[paste(i,j)]] <- j
    pch[[paste(i,j)]] <- (i-1)*15+j
  }
}
leg <- expression(paste(Delta ==   0, ", ", italic(B)[3] == 0, "  "),
                  paste(Delta == 0.5, ", ", italic(B)[3] == 0, "  "),
                  paste(Delta ==   0, ", ", italic(B)[3] == 1),
                  paste(Delta == 0.5, ", ", italic(B)[3] == 1))
legend("top", legend=leg, lty=unlist(lty), col="black", #col=unlist(colour),
    bty="n", pch=unlist(pch), ncol=2)
mtext("(a)", side=3, line=1, adj=0)
#dev.off()

#}}}
# figure: effect of k; symmetric case {{{
gg.file <- "../runs/F_k_SS/gg.Rdata"
load(gg.file)

es <- (gg$C3 == 0 | gg$C3 == 1) & (gg$B3 == 0 | gg$B3 == 1)
ggs <- gg[es,]

es <- ggs$F_k_SS == round(ggs$F_k_SS, 0)
ggs <- ggs[es,]

#pdf(file="fig-F_k_SS-male_care.pdf", width=7, height=5.5)
plot(I(1-male.care)~F_k_SS, ggs, type="n", bty="l", ylim=c(0,0.6),
    xlab=expression(paste("strength of sexual selection on males, ",
            italic(k[m]))),
    ylab="proportion of male care")
abline(h=0.5, lty=2, col="grey")
abline(v=1, lty=2, col="grey")
leg <- vector()
lty <- list()
colour <- list()
pch <- list()
x <- sort(unique(ggs$F_k_SS))
b3 <- sort(unique(ggs$B3))
c3 <- sort(unique(ggs$C3))
for(i in 1:length(b3)) {
  for(j in 1:length(c3)) {
    es <- ggs$B3 == b3[i] & ggs$C3 == c3[j]
    y <- tapply((1-ggs$male.care[es]), ggs$F_k_SS[es], median)
    #y.sd <- tapply(ggs$male.care[es], ggs$F_MU_O[es], sd)
    y.iqr <- matrix(unlist(tapply((1-ggs$male.care[es]), ggs$F_k_SS[es],
                quantile, probs=c(0.25, 0.75))), ncol=2, byrow=TRUE)
    lines(x, y, col=1, lty=3-i, lwd=1)
    points(x, y, col=1, pch=(i-1)*15+j)
    #segments(x, y+y.sd, x, y-y.sd, col=1, lty=i)
    arrows(x, y.iqr[,1], x, y.iqr[,2], col=1, lty=3-i, length=0.05,
        angle=90, code=3)
    #leg[paste(i,j)] <- expression(paste("C3=", c3[j], "B3=", b3[i])
    lty[[paste(i,j)]] <- 3-i
    colour[[paste(i,j)]] <- j
    pch[[paste(i,j)]] <- (i-1)*15+j
  }
}
leg <- expression(paste(italic(C)[3] == 0, ", ", italic(B)[3] == 0, "  "),
                  paste(italic(C)[3] == 1, ", ", italic(B)[3] == 0, "  "),
                  paste(italic(C)[3] == 0, ", ", italic(B)[3] == 1),
                  paste(italic(C)[3] == 1, ", ", italic(B)[3] == 1))
legend("top", legend=leg, lty=unlist(lty), col="black", #col=unlist(colour),
    bty="n", pch=unlist(pch), ncol=2)
mtext("(b)", side=3, line=1, adj=0)
#dev.off()

#}}}
# figure: effect of F_MU_O; asymmetric case {{{
gg.file <- "../runs/a-F_MU_O/gg.Rdata"
load(gg.file)

#es <- (gg$C12 == 1 | gg$C12 == 2) & (gg$B3 == 0 | gg$B3 == 1)
es <- (gg$C12 == 1 | gg$C12 == 1.5) & (gg$B3 == 0 | gg$B3 == 1)
ggs <- gg[es,]

### division of labour
#pdf(file="fig-a-F_MU_O-female_care.pdf", width=7, height=6)
plot(male.care~F_MU_O, ggs, type="n", bty="l", 
    xlab=expression(paste("mortality of caring females, ",
             italic(mu[list(C,f)]))), 
    ylab="proportion of female care")
abline(h=0.5, lty=2, col="grey")
abline(v=0.2, lty=2, col="grey")
leg <- list()
lty <- list()
colour <- list()
pch <- list()
x <- unique(gg$F_MU_O)
b3 <- sort(unique(ggs$B3))
c3 <- sort(unique(ggs$C12))
for(i in 1:length(b3)) {
  for(j in 1:length(c3)) {
    es <- ggs$B3 == b3[i] & ggs$C12 == c3[j]
    y <- tapply((1-ggs$male.care[es]), ggs$F_MU_O[es], median)
    #y.sd <- tapply(ggs$male.care[es], ggs$F_MU_O[es], sd)
    y.iqr <- matrix(unlist(tapply((1-ggs$male.care[es]), ggs$F_MU_O[es],
                quantile, probs=c(0.25, 0.75))), ncol=2, byrow=TRUE)
    lines(x, y, col=1, lty=3-i, lwd=1)
    points(x, y, col=1, pch=(i-1)*15+j)
    #segments(x, y+y.sd, x, y-y.sd, col=1, lty=i)
    arrows(x, y.iqr[,1], x, y.iqr[,2], col=1, lty=3-i, length=0.05,
        angle=90, code=3)
    leg[[paste(i,j)]] <- paste("Ci=", c3[j], "B3=", b3[i])
    lty[[paste(i,j)]] <- 3-i
    colour[[paste(i,j)]] <- j
    pch[[paste(i,j)]] <- (i-1)*15+j
  }
}
leg <- expression(paste(Delta == 0, ", ", italic(B)[3] == 0, "  "),
                  paste(Delta == 0.5, ", ", italic(B)[3] == 0, "  "),
                  paste(Delta == 0, ", ", italic(B)[3] == 1),
                  paste(Delta == 0.5, ", ", italic(B)[3] == 1))
legend("topright", legend=leg, lty=unlist(lty), col="black", #col=unlist(colour),
    bty="n", pch=unlist(pch))
mtext("(c)", side=3, line=1, adj=0)
#dev.off()
#}}}
# figure: effect of F_MU_O; symmetric case {{{
gg.file <- "../runs/F_MU_O/gg.Rdata"
load(gg.file)

es <- (gg$C3 == 0 | gg$C3 == 1) & (gg$B3 == 0 | gg$B3 == 1)
ggs <- gg[es,]

### division of labour
#pdf(file="fig-F_MU_O-female_care.pdf", width=7, height=6)
plot(male.care~F_MU_O, ggs, type="n", bty="l", 
    xlab=expression(paste("mortality of caring females, ",
             italic(mu[list(C,f)]))), 
    ylab="proportion of female care")
abline(h=0.5, lty=2, col="grey")
abline(v=0.2, lty=2, col="grey")
leg <- list()
lty <- list()
colour <- list()
pch <- list()
x <- unique(gg$F_MU_O)
b3 <- sort(unique(ggs$B3))
c3 <- sort(unique(ggs$C3))
for(i in 1:length(b3)) {
  for(j in 1:length(c3)) {
    es <- ggs$B3 == b3[i] & ggs$C3 == c3[j]
    y <- tapply((1-ggs$male.care[es]), ggs$F_MU_O[es], median)
    #y.sd <- tapply(ggs$male.care[es], ggs$F_MU_O[es], sd)
    y.iqr <- matrix(unlist(tapply((1-ggs$male.care[es]), ggs$F_MU_O[es],
                quantile, probs=c(0.25, 0.75))), ncol=2, byrow=TRUE)
    lines(x, y, col=1, lty=3-i, lwd=1)
    points(x, y, col=1, pch=(i-1)*15+j)
    #segments(x, y+y.sd, x, y-y.sd, col=1, lty=i)
    arrows(x, y.iqr[,1], x, y.iqr[,2], col=1, lty=3-i, length=0.05,
        angle=90, code=3)
    leg[[paste(i,j)]] <- paste("Ci=", c3[j], "B3=", b3[i])
    lty[[paste(i,j)]] <- 3-i
    colour[[paste(i,j)]] <- j
    pch[[paste(i,j)]] <- (i-1)*15+j
  }
}
leg <- expression(paste(italic(C)[3] == 0, ", ", italic(B)[3] == 0, "  "),
                  paste(italic(C)[3] == 1, ", ", italic(B)[3] == 0, "  "),
                  paste(italic(C)[3] == 0, ", ", italic(B)[3] == 1),
                  paste(italic(C)[3] == 1, ", ", italic(B)[3] == 1))
legend("topright", legend=leg, lty=unlist(lty), col="black", #col=unlist(colour),
    bty="n", pch=unlist(pch))
mtext("(d)", side=3, line=1, adj=0)
#dev.off()
#}}}
layout(1)
par(op)
dev.off()
#}}}

# figure-4: effect of sex specific mortality {{{
pdf(file="figure-4.pdf", width=10, height=10)
op <- par(mar=c(5,4,2,1)+0.1)
layout(matrix(1:4, ncol=2, byrow=TRUE))
# figure: effect of k; asymmetric case {{{
gg.file <- "../runs/a-F_k_SS/gg.Rdata"
load(gg.file)

#es <- (gg$C12 == 1 | gg$C12 == 2) & (gg$B3 == 0 | gg$B3 == 1)
es <- (gg$C12 == 1 | gg$C12 == 1.5) & (gg$B3 == 0 | gg$B3 == 1)
ggs <- gg[es,]

#es <- ggs$F_k_SS == round(ggs$F_k_SS, 0)
#ggs <- ggs[es,]
ggs$tot.care <- ggs$E.m + ggs$E.f

leg <- vector()
lty <- list()
colour <- list()
pch <- list()
x <- sort(unique(ggs$F_k_SS))
b3 <- sort(unique(ggs$B3))
c3 <- sort(unique(ggs$C12))
agg <- data.frame()
for(i in 1:length(b3)) {
  for(j in 1:length(c3)) {
    es <- ggs$B3 == b3[i] & ggs$C12 == c3[j]
    z <- tapply((ggs$div.labour[es]), ggs$F_k_SS[es], median)
    y <- tapply(ggs$tot.care[es], ggs$F_k_SS[es], median)
    yy <- cbind(unique(ggs$F_k_SS[es]), z, y)
    yy <- as.data.frame(yy)
    colnames(yy) <- c("F_k_SS", "div.labour", "tot.care")
    yy$c3 <- NA
    yy$b3 <- NA
    yy$c3 <- c3[j]
    yy$b3 <- b3[i]
    agg <- rbind(agg, yy)
    lty[[paste(i,j)]] <- 3-i
    colour[[paste(i,j)]] <- j
    pch[[paste(i,j)]] <- (i-1)*15+j
  }
}
agg$case <- paste(agg$b3, agg$c3, sep=":")
agg <- agg[order(agg$case, agg$F_k_SS),]
#tc <- matrix(agg$tot.care, ncol=4)
#tc <- apply(tc, 2, function(z) z/tc[,1])
#agg$tot.care <- as.numeric(tc)
plot(tot.care~div.labour, agg, type="n", xlab="division of labour",
     ylab="total care", bty="l")
cases <- unique(agg$case)
for(i in 1:length(cases)) {
  es <- agg$case == cases[i]
  points(tot.care~div.labour, agg, subset=es, pch=pch[[i]],
         col=colour[[i]])
}
leg <- expression(paste(Delta ==   0, ", ", italic(B)[3] == 0, "  "),
                  paste(Delta == 0.5, ", ", italic(B)[3] == 0, "  "),
                  paste(Delta ==   0, ", ", italic(B)[3] == 1),
                  paste(Delta == 0.5, ", ", italic(B)[3] == 1))
legend("top", legend=leg, col=unlist(colour), #lty=unlist(lty), 
    bty="n", pch=unlist(pch), ncol=2)
mtext("(a)", side=3, line=1, adj=0)
#dev.off()

#}}}
# figure: effect of k; symmetric case {{{
gg.file <- "../runs/F_k_SS/gg.Rdata"
load(gg.file)

#es <- (gg$C12 == 1 | gg$C12 == 2) & (gg$B3 == 0 | gg$B3 == 1)
es <- (gg$C3 == 0 | gg$C3 == 1) & (gg$B3 == 0 | gg$B3 == 1)
ggs <- gg[es,]

#es <- ggs$F_k_SS == round(ggs$F_k_SS, 0)
#ggs <- ggs[es,]
ggs$tot.care <- ggs$E.m + ggs$E.f

leg <- vector()
lty <- list()
colour <- list()
pch <- list()
x <- sort(unique(ggs$F_k_SS))
b3 <- sort(unique(ggs$B3))
c3 <- sort(unique(ggs$C3))
agg <- data.frame()
for(i in 1:length(b3)) {
  for(j in 1:length(c3)) {
    es <- ggs$B3 == b3[i] & ggs$C3 == c3[j]
    z <- tapply((ggs$div.labour[es]), ggs$F_k_SS[es], median)
    y <- tapply(ggs$tot.care[es], ggs$F_k_SS[es], median)
    yy <- cbind(unique(ggs$F_k_SS[es]), z, y)
    yy <- as.data.frame(yy)
    colnames(yy) <- c("F_k_SS", "div.labour", "tot.care")
    yy$c3 <- NA
    yy$b3 <- NA
    yy$c3 <- c3[j]
    yy$b3 <- b3[i]
    agg <- rbind(agg, yy)
    lty[[paste(i,j)]] <- 3-i
    colour[[paste(i,j)]] <- j
    pch[[paste(i,j)]] <- (i-1)*15+j
  }
}
agg$case <- paste(agg$b3, agg$c3, sep=":")
agg <- agg[order(agg$case, agg$F_k_SS),]
#tc <- matrix(agg$tot.care, ncol=4)
#tc <- apply(tc, 2, function(z) z/tc[,1])
#agg$tot.care <- as.numeric(tc)
plot(tot.care~div.labour, agg, type="n", xlab="division of labour",
     ylab="total care", bty="l")
cases <- unique(agg$case)
for(i in 1:length(cases)) {
  es <- agg$case == cases[i]
  points(tot.care~div.labour, agg, subset=es, pch=pch[[i]],
         col=colour[[i]])
}
leg <- expression(paste(italic(C)[3] == 0, ", ", italic(B)[3] == 0, "  "),
                  paste(italic(C)[3] == 1, ", ", italic(B)[3] == 0, "  "),
                  paste(italic(C)[3] == 0, ", ", italic(B)[3] == 1),
                  paste(italic(C)[3] == 1, ", ", italic(B)[3] == 1))
legend("top", legend=leg, col=unlist(colour), #lty=unlist(lty), 
    bty="n", pch=unlist(pch), ncol=2)
mtext("(b)", side=3, line=1, adj=0)
#dev.off()

#}}}
# figure: effect of k; asymmetric case {{{
gg.file <- "../runs/a-F_k_SS/gg.Rdata"
load(gg.file)

#es <- (gg$C12 == 1 | gg$C12 == 2) & (gg$B3 == 0 | gg$B3 == 1)
es <- (gg$C12 == 1 | gg$C12 == 1.5) & (gg$B3 == 0 | gg$B3 == 1)
ggs <- gg[es,]

#es <- ggs$F_k_SS == round(ggs$F_k_SS, 0)
#ggs <- ggs[es,]

leg <- vector()
lty <- list()
colour <- list()
pch <- list()
x <- sort(unique(ggs$F_k_SS))
b3 <- sort(unique(ggs$B3))
c3 <- sort(unique(ggs$C12))
agg <- data.frame()
for(i in 1:length(b3)) {
  for(j in 1:length(c3)) {
    es <- ggs$B3 == b3[i] & ggs$C12 == c3[j]
    z <- tapply((ggs$div.labour[es]), ggs$F_k_SS[es], median)
    y <- tapply(ggs$tot.pop.size[es], ggs$F_k_SS[es], median)
    yy <- cbind(unique(ggs$F_k_SS[es]), z, y)
    yy <- as.data.frame(yy)
    colnames(yy) <- c("F_k_SS", "div.labour", "tot.pop.size")
    yy$c3 <- NA
    yy$b3 <- NA
    yy$c3 <- c3[j]
    yy$b3 <- b3[i]
    agg <- rbind(agg, yy)
    lty[[paste(i,j)]] <- 3-i
    colour[[paste(i,j)]] <- j
    pch[[paste(i,j)]] <- (i-1)*15+j
  }
}
agg$case <- paste(agg$b3, agg$c3, sep=":")
agg <- agg[order(agg$case, agg$F_k_SS),]
#tc <- matrix(agg$tot.pop.size, ncol=4)
#tc <- apply(tc, 2, function(z) z/tc[,1])
#agg$tot.pop.size <- as.numeric(tc)
plot(tot.pop.size~div.labour, agg, type="n", xlab="division of labour",
     ylab="population size", bty="l")
cases <- unique(agg$case)
for(i in 1:length(cases)) {
  es <- agg$case == cases[i]
  points(tot.pop.size~div.labour, agg, subset=es, pch=pch[[i]],
         col=colour[[i]])
}
leg <- expression(paste(Delta ==   0, ", ", italic(B)[3] == 0, "  "),
                  paste(Delta == 0.5, ", ", italic(B)[3] == 0, "  "),
                  paste(Delta ==   0, ", ", italic(B)[3] == 1),
                  paste(Delta == 0.5, ", ", italic(B)[3] == 1))
legend("top", legend=leg, col=unlist(colour), #lty=unlist(lty), 
    bty="n", pch=unlist(pch), ncol=2)
mtext("(c)", side=3, line=1, adj=0)
#dev.off()

#}}}
# figure: effect of k; symmetric case {{{
gg.file <- "../runs/F_k_SS/gg.Rdata"
load(gg.file)

#es <- (gg$C12 == 1 | gg$C12 == 2) & (gg$B3 == 0 | gg$B3 == 1)
es <- (gg$C3 == 0 | gg$C3 == 1) & (gg$B3 == 0 | gg$B3 == 1)
ggs <- gg[es,]

#es <- ggs$F_k_SS == round(ggs$F_k_SS, 0)
#ggs <- ggs[es,]

leg <- vector()
lty <- list()
colour <- list()
pch <- list()
x <- sort(unique(ggs$F_k_SS))
b3 <- sort(unique(ggs$B3))
c3 <- sort(unique(ggs$C3))
agg <- data.frame()
for(i in 1:length(b3)) {
  for(j in 1:length(c3)) {
    es <- ggs$B3 == b3[i] & ggs$C3 == c3[j]
    z <- tapply((ggs$div.labour[es]), ggs$F_k_SS[es], median)
    y <- tapply(ggs$tot.pop.size[es], ggs$F_k_SS[es], median)
    yy <- cbind(unique(ggs$F_k_SS[es]), z, y)
    yy <- as.data.frame(yy)
    colnames(yy) <- c("F_k_SS", "div.labour", "tot.pop.size")
    yy$c3 <- NA
    yy$b3 <- NA
    yy$c3 <- c3[j]
    yy$b3 <- b3[i]
    agg <- rbind(agg, yy)
    lty[[paste(i,j)]] <- 3-i
    colour[[paste(i,j)]] <- j
    pch[[paste(i,j)]] <- (i-1)*15+j
  }
}
agg$case <- paste(agg$b3, agg$c3, sep=":")
agg <- agg[order(agg$case, agg$F_k_SS),]
#tc <- matrix(agg$tot.pop.size, ncol=4)
#tc <- apply(tc, 2, function(z) z/tc[,1])
#agg$tot.pop.size <- as.numeric(tc)
plot(tot.pop.size~div.labour, agg, type="n", xlab="division of labour",
     ylab="population size", bty="l")
cases <- unique(agg$case)
for(i in 1:length(cases)) {
  es <- agg$case == cases[i]
  points(tot.pop.size~div.labour, agg, subset=es, pch=pch[[i]],
         col=colour[[i]])
}
leg <- expression(paste(italic(C)[3] == 0, ", ", italic(B)[3] == 0, "  "),
                  paste(italic(C)[3] == 1, ", ", italic(B)[3] == 0, "  "),
                  paste(italic(C)[3] == 0, ", ", italic(B)[3] == 1),
                  paste(italic(C)[3] == 1, ", ", italic(B)[3] == 1))
legend("top", legend=leg, col=unlist(colour), #lty=unlist(lty), 
    bty="n", pch=unlist(pch), ncol=2)
mtext("(d)", side=3, line=1, adj=0)
#dev.off()

#}}}
layout(1)
par(op)
dev.off()
#}}}

# figure-S6: effect of sexual selection {{{
pdf(file="figure-S6.pdf", width=10, height=10)
op <- par(mar=c(5,4,2,1)+0.1)
layout(matrix(1:4, ncol=2, byrow=TRUE))
# figure: effect of k; asymmetric case {{{
gg.file <- "../runs/a-F_k_SS/gg.Rdata"
load(gg.file)

#es <- (gg$C12 == 1 | gg$C12 == 2) & (gg$B3 == 0 | gg$B3 == 1)
es <- (gg$C12 == 1 | gg$C12 == 1.5) & (gg$B3 == 0 | gg$B3 == 1)
ggs <- gg[es,]

es <- ggs$F_k_SS == round(ggs$F_k_SS, 0)
ggs <- ggs[es,]

#pdf(file="fig-a-F_k_SS-male_care.pdf", width=7, height=5.5)
plot(I(E.m+E.f)~F_k_SS, ggs, type="n", bty="l", 
    xlab=expression(paste("strength of sexual selection on males, ",
            italic(k[m]))),
    ylab="total care")
abline(h=0.5, lty=2, col="grey")
abline(v=1, lty=2, col="grey")
leg <- vector()
lty <- list()
colour <- list()
pch <- list()
x <- sort(unique(ggs$F_k_SS))
b3 <- sort(unique(ggs$B3))
c3 <- sort(unique(ggs$C12))
for(i in 1:length(b3)) {
  for(j in 1:length(c3)) {
    es <- ggs$B3 == b3[i] & ggs$C12 == c3[j]
    y <- tapply((ggs$E.m[es]+ggs$E.f[es]), ggs$F_k_SS[es], median)
    #y.sd <- tapply(ggs$male.care[es], ggs$F_MU_O[es], sd)
    y.iqr <- matrix(unlist(tapply((ggs$E.m[es]+ggs$E.f[es]), ggs$F_k_SS[es],
                quantile, probs=c(0.25, 0.75))), ncol=2, byrow=TRUE)
    lines(x, y, col=j, lty=3-i, lwd=1)
    points(x, y, col=j, pch=(i-1)*15+j)
    #segments(x, y+y.sd, x, y-y.sd, col=j, lty=i)
    arrows(x, y.iqr[,1], x, y.iqr[,2], col=j, lty=3-i, length=0.05,
        angle=90, code=3)
    #leg[paste(i,j)] <- expression(paste("C12=", c3[j], "B3=", b3[i])
    lty[[paste(i,j)]] <- 3-i
    colour[[paste(i,j)]] <- j
    pch[[paste(i,j)]] <- (i-1)*15+j
  }
}
leg <- expression(paste(Delta ==   0, ", ", italic(B)[3] == 0, "  "),
                  paste(Delta == 0.5, ", ", italic(B)[3] == 0, "  "),
                  paste(Delta ==   0, ", ", italic(B)[3] == 1),
                  paste(Delta == 0.5, ", ", italic(B)[3] == 1))
legend("top", legend=leg, lty=unlist(lty), col=unlist(colour),
    bty="n", pch=unlist(pch), ncol=2)
mtext("(a)", side=3, line=1, adj=0)
#dev.off()

#}}}
# figure: effect of k; symmetric case {{{
gg.file <- "../runs/F_k_SS/gg.Rdata"
load(gg.file)

es <- (gg$C3 == 0 | gg$C3 == 1) & (gg$B3 == 0 | gg$B3 == 1)
ggs <- gg[es,]

es <- ggs$F_k_SS == round(ggs$F_k_SS, 0)
ggs <- ggs[es,]

#pdf(file="fig-F_k_SS-male_care.pdf", width=7, height=5.5)
plot(I(E.m+E.f)~F_k_SS, ggs, type="n", bty="l", 
    xlab=expression(paste("strength of sexual selection on males, ",
            italic(k[m]))),
    ylab="total care")
abline(h=0.5, lty=2, col="grey")
abline(v=1, lty=2, col="grey")
leg <- vector()
lty <- list()
colour <- list()
pch <- list()
x <- sort(unique(ggs$F_k_SS))
b3 <- sort(unique(ggs$B3))
c3 <- sort(unique(ggs$C3))
for(i in 1:length(b3)) {
  for(j in 1:length(c3)) {
    es <- ggs$B3 == b3[i] & ggs$C3 == c3[j]
    y <- tapply((ggs$E.m[es]+ggs$E.f[es]), ggs$F_k_SS[es], median)
    #y.sd <- tapply(ggs$male.care[es], ggs$F_MU_O[es], sd)
    y.iqr <- matrix(unlist(tapply((ggs$E.m[es]+ggs$E.f[es]), ggs$F_k_SS[es],
                quantile, probs=c(0.25, 0.75))), ncol=2, byrow=TRUE)
    lines(x, y, col=j, lty=3-i, lwd=1)
    points(x, y, col=j, pch=(i-1)*15+j)
    #segments(x, y+y.sd, x, y-y.sd, col=j, lty=i)
    arrows(x, y.iqr[,1], x, y.iqr[,2], col=j, lty=3-i, length=0.05,
        angle=90, code=3)
    #leg[paste(i,j)] <- expression(paste("C3=", c3[j], "B3=", b3[i])
    lty[[paste(i,j)]] <- 3-i
    colour[[paste(i,j)]] <- j
    pch[[paste(i,j)]] <- (i-1)*15+j
  }
}
leg <- expression(paste(italic(C)[3] == 0, ", ", italic(B)[3] == 0, "  "),
                  paste(italic(C)[3] == 1, ", ", italic(B)[3] == 0, "  "),
                  paste(italic(C)[3] == 0, ", ", italic(B)[3] == 1),
                  paste(italic(C)[3] == 1, ", ", italic(B)[3] == 1))
legend("top", legend=leg, lty=unlist(lty), col=unlist(colour),
    bty="n", pch=unlist(pch), ncol=2)
mtext("(b)", side=3, line=1, adj=0)
#dev.off()

#}}}
# figure: effect of k; asymmetric case {{{
gg.file <- "../runs/a-F_k_SS/gg.Rdata"
load(gg.file)

#es <- (gg$C12 == 1 | gg$C12 == 2) & (gg$B3 == 0 | gg$B3 == 1)
es <- (gg$C12 == 1 | gg$C12 == 1.5) & (gg$B3 == 0 | gg$B3 == 1)
ggs <- gg[es,]

es <- ggs$F_k_SS == round(ggs$F_k_SS, 0)
ggs <- ggs[es,]

#pdf(file="fig-a-F_k_SS-male_care.pdf", width=7, height=5.5)
plot(I(tot.pop.size)~F_k_SS, ggs, type="n", bty="l", #ylim=c(0,0.6),
    xlab=expression(paste("strength of sexual selection on males, ",
            italic(k[m]))),
    ylab="population size")
abline(h=0.5, lty=2, col="grey")
abline(v=1, lty=2, col="grey")
leg <- vector()
lty <- list()
colour <- list()
pch <- list()
x <- sort(unique(ggs$F_k_SS))
b3 <- sort(unique(ggs$B3))
c3 <- sort(unique(ggs$C12))
for(i in 1:length(b3)) {
  for(j in 1:length(c3)) {
    es <- ggs$B3 == b3[i] & ggs$C12 == c3[j]
    y <- tapply((ggs$tot.pop.size[es]), ggs$F_k_SS[es], median)
    #y.sd <- tapply(ggs$tot.pop.size[es], ggs$F_MU_O[es], sd)
    y.iqr <- matrix(unlist(tapply((ggs$tot.pop.size[es]), ggs$F_k_SS[es],
                quantile, probs=c(0.25, 0.75))), ncol=2, byrow=TRUE)
    lines(x, y, col=j, lty=3-i, lwd=1)
    points(x, y, col=j, pch=(i-1)*15+j)
    #segments(x, y+y.sd, x, y-y.sd, col=j, lty=i)
    arrows(x, y.iqr[,1], x, y.iqr[,2], col=j, lty=3-i, length=0.05,
        angle=90, code=3)
    #leg[paste(i,j)] <- expression(paste("C12=", c3[j], "B3=", b3[i])
    lty[[paste(i,j)]] <- 3-i
    colour[[paste(i,j)]] <- j
    pch[[paste(i,j)]] <- (i-1)*15+j
  }
}
leg <- expression(paste(Delta ==   0, ", ", italic(B)[3] == 0, "  "),
                  paste(Delta == 0.5, ", ", italic(B)[3] == 0, "  "),
                  paste(Delta ==   0, ", ", italic(B)[3] == 1),
                  paste(Delta == 0.5, ", ", italic(B)[3] == 1))
legend("top", legend=leg, lty=unlist(lty), col=unlist(colour),
    bty="n", pch=unlist(pch), ncol=2)
mtext("(c)", side=3, line=1, adj=0)
#dev.off()

#}}}
# figure: effect of k; symmetric case {{{
gg.file <- "../runs/F_k_SS/gg.Rdata"
load(gg.file)

es <- (gg$C3 == 0 | gg$C3 == 1) & (gg$B3 == 0 | gg$B3 == 1)
ggs <- gg[es,]

es <- ggs$F_k_SS == round(ggs$F_k_SS, 0)
ggs <- ggs[es,]

plot(I(tot.pop.size)~F_k_SS, ggs, type="n", bty="l", #ylim=c(0,0.6),
    xlab=expression(paste("strength of sexual selection on males, ",
            italic(k[m]))),
    ylab="population size")
abline(h=0.5, lty=2, col="grey")
abline(v=1, lty=2, col="grey")
leg <- vector()
lty <- list()
colour <- list()
pch <- list()
x <- sort(unique(ggs$F_k_SS))
b3 <- sort(unique(ggs$B3))
c3 <- sort(unique(ggs$C3))
for(i in 1:length(b3)) {
  for(j in 1:length(c3)) {
    es <- ggs$B3 == b3[i] & ggs$C3 == c3[j]
    y <- tapply((ggs$tot.pop.size[es]), ggs$F_k_SS[es], median)
    #y.sd <- tapply(ggs$tot.pop.size[es], ggs$F_MU_O[es], sd)
    y.iqr <- matrix(unlist(tapply((ggs$tot.pop.size[es]), ggs$F_k_SS[es],
                quantile, probs=c(0.25, 0.75))), ncol=2, byrow=TRUE)
    lines(x, y, col=j, lty=3-i, lwd=1)
    points(x, y, col=j, pch=(i-1)*15+j)
    #segments(x, y+y.sd, x, y-y.sd, col=j, lty=i)
    arrows(x, y.iqr[,1], x, y.iqr[,2], col=j, lty=3-i, length=0.05,
        angle=90, code=3)
    #leg[paste(i,j)] <- expression(paste("C3=", c3[j], "B3=", b3[i])
    lty[[paste(i,j)]] <- 3-i
    colour[[paste(i,j)]] <- j
    pch[[paste(i,j)]] <- (i-1)*15+j
  }
}
leg <- expression(paste(italic(C)[3] == 0, ", ", italic(B)[3] == 0, "  "),
                  paste(italic(C)[3] == 1, ", ", italic(B)[3] == 0, "  "),
                  paste(italic(C)[3] == 0, ", ", italic(B)[3] == 1),
                  paste(italic(C)[3] == 1, ", ", italic(B)[3] == 1))
legend("top", legend=leg, lty=unlist(lty), col=unlist(colour),
    bty="n", pch=unlist(pch), ncol=2)
mtext("(d)", side=3, line=1, adj=0)
#dev.off()

#}}}
layout(1)
par(op)
dev.off()
#}}}

# figure-S5: effect of sex specific mortality {{{
pdf(file="figure-S5.pdf", width=10, height=10)
op <- par(mar=c(5,4,2,1)+0.1)
layout(matrix(1:4, ncol=2, byrow=TRUE))
# figure: effect of F_MU_O; asymmetric case {{{
gg.file <- "../runs/a-F_MU_O/gg.Rdata"
load(gg.file)

#es <- (gg$C12 == 1 | gg$C12 == 2) & (gg$B3 == 0 | gg$B3 == 1)
es <- (gg$C12 == 1 | gg$C12 == 1.5) & (gg$B3 == 0 | gg$B3 == 1)
ggs <- gg[es,]

### division of labour
#pdf(file="fig-a-F_MU_O-female_care.pdf", width=7, height=6)
plot(I(E.m+E.f)~F_MU_O, ggs, type="n", bty="l", 
    xlab=expression(paste("mortality of caring females, ",
             italic(mu[list(C,f)]))), 
    ylab="total care")
abline(h=0.5, lty=2, col="grey")
abline(v=0.2, lty=2, col="grey")
leg <- list()
lty <- list()
colour <- list()
pch <- list()
x <- unique(gg$F_MU_O)
b3 <- sort(unique(ggs$B3))
c3 <- sort(unique(ggs$C12))
for(i in 1:length(b3)) {
  for(j in 1:length(c3)) {
    es <- ggs$B3 == b3[i] & ggs$C12 == c3[j]
    y <- tapply((ggs$E.m[es]+ggs$E.f[es]), ggs$F_MU_O[es], median)
    #y.sd <- tapply(ggs$male.care[es], ggs$F_MU_O[es], sd)
    y.iqr <- matrix(unlist(tapply((ggs$E.m[es]+ggs$E.f[es]), ggs$F_MU_O[es],
                quantile, probs=c(0.25, 0.75))), ncol=2, byrow=TRUE)
    lines(x, y, col=j, lty=3-i, lwd=1)
    points(x, y, col=j, pch=(i-1)*15+j)
    #segments(x, y+y.sd, x, y-y.sd, col=j, lty=i)
    arrows(x, y.iqr[,1], x, y.iqr[,2], col=j, lty=3-i, length=0.05,
        angle=90, code=3)
    leg[[paste(i,j)]] <- paste("Ci=", c3[j], "B3=", b3[i])
    lty[[paste(i,j)]] <- 3-i
    colour[[paste(i,j)]] <- j
    pch[[paste(i,j)]] <- (i-1)*15+j
  }
}
leg <- expression(paste(Delta == 0, ", ", italic(B)[3] == 0, "  "),
                  paste(Delta == 0.5, ", ", italic(B)[3] == 0, "  "),
                  paste(Delta == 0, ", ", italic(B)[3] == 1),
                  paste(Delta == 0.5, ", ", italic(B)[3] == 1))
legend("topright", legend=leg, lty=unlist(lty), col=unlist(colour),
    bty="n", pch=unlist(pch))
mtext("(a)", side=3, line=1, adj=0)
#dev.off()
#}}}
# figure: effect of F_MU_O; symmetric case {{{
gg.file <- "../runs/F_MU_O/gg.Rdata"
load(gg.file)

es <- (gg$C3 == 0 | gg$C3 == 1) & (gg$B3 == 0 | gg$B3 == 1)
ggs <- gg[es,]

### division of labour
#pdf(file="fig-F_MU_O-female_care.pdf", width=7, height=6)
plot(I(E.m+E.f)~F_MU_O, ggs, type="n", bty="l", 
    xlab=expression(paste("mortality of caring females, ",
             italic(mu[list(C,f)]))), 
    ylab="total care")
abline(h=0.5, lty=2, col="grey")
abline(v=0.2, lty=2, col="grey")
leg <- list()
lty <- list()
colour <- list()
pch <- list()
x <- unique(gg$F_MU_O)
b3 <- sort(unique(ggs$B3))
c3 <- sort(unique(ggs$C3))
for(i in 1:length(b3)) {
  for(j in 1:length(c3)) {
    es <- ggs$B3 == b3[i] & ggs$C3 == c3[j]
    y <- tapply((ggs$E.m[es]+ggs$E.f[es]), ggs$F_MU_O[es], median)
    #y.sd <- tapply(ggs$male.care[es], ggs$F_MU_O[es], sd)
    y.iqr <- matrix(unlist(tapply((ggs$E.m[es]+ggs$E.f[es]), ggs$F_MU_O[es],
                quantile, probs=c(0.25, 0.75))), ncol=2, byrow=TRUE)
    lines(x, y, col=j, lty=3-i, lwd=1)
    points(x, y, col=j, pch=(i-1)*15+j)
    #segments(x, y+y.sd, x, y-y.sd, col=j, lty=i)
    arrows(x, y.iqr[,1], x, y.iqr[,2], col=j, lty=3-i, length=0.05,
        angle=90, code=3)
    leg[[paste(i,j)]] <- paste("Ci=", c3[j], "B3=", b3[i])
    lty[[paste(i,j)]] <- 3-i
    colour[[paste(i,j)]] <- j
    pch[[paste(i,j)]] <- (i-1)*15+j
  }
}
leg <- expression(paste(italic(C)[3] == 0, ", ", italic(B)[3] == 0, "  "),
                  paste(italic(C)[3] == 1, ", ", italic(B)[3] == 0, "  "),
                  paste(italic(C)[3] == 0, ", ", italic(B)[3] == 1),
                  paste(italic(C)[3] == 1, ", ", italic(B)[3] == 1))
legend("topright", legend=leg, lty=unlist(lty), col=unlist(colour),
    bty="n", pch=unlist(pch))
mtext("(b)", side=3, line=1, adj=0)
#dev.off()
#}}}
# figure: effect of F_MU_O; asymmetric case {{{
gg.file <- "../runs/a-F_MU_O/gg.Rdata"
load(gg.file)

#es <- (gg$C12 == 1 | gg$C12 == 2) & (gg$B3 == 0 | gg$B3 == 1)
es <- (gg$C12 == 1 | gg$C12 == 1.5) & (gg$B3 == 0 | gg$B3 == 1)
ggs <- gg[es,]

### division of labour
#pdf(file="fig-a-F_MU_O-fetot.pop.size.pdf", width=7, height=6)
plot(tot.pop.size~F_MU_O, ggs, type="n", bty="l", 
    xlab=expression(paste("mortality of caring females, ",
             italic(mu[list(C,f)]))), 
    ylab="population size")
abline(h=0.5, lty=2, col="grey")
abline(v=0.2, lty=2, col="grey")
leg <- list()
lty <- list()
colour <- list()
pch <- list()
x <- unique(gg$F_MU_O)
b3 <- sort(unique(ggs$B3))
c3 <- sort(unique(ggs$C12))
for(i in 1:length(b3)) {
  for(j in 1:length(c3)) {
    es <- ggs$B3 == b3[i] & ggs$C12 == c3[j]
    y <- tapply((ggs$tot.pop.size[es]), ggs$F_MU_O[es], median)
    #y.sd <- tapply(ggs$tot.pop.size[es], ggs$F_MU_O[es], sd)
    y.iqr <- matrix(unlist(tapply((ggs$tot.pop.size[es]), ggs$F_MU_O[es],
                quantile, probs=c(0.25, 0.75))), ncol=2, byrow=TRUE)
    lines(x, y, col=j, lty=3-i, lwd=1)
    points(x, y, col=j, pch=(i-1)*15+j)
    #segments(x, y+y.sd, x, y-y.sd, col=j, lty=i)
    arrows(x, y.iqr[,1], x, y.iqr[,2], col=j, lty=3-i, length=0.05,
        angle=90, code=3)
    leg[[paste(i,j)]] <- paste("Ci=", c3[j], "B3=", b3[i])
    lty[[paste(i,j)]] <- 3-i
    colour[[paste(i,j)]] <- j
    pch[[paste(i,j)]] <- (i-1)*15+j
  }
}
leg <- expression(paste(Delta == 0, ", ", italic(B)[3] == 0, "  "),
                  paste(Delta == 0.5, ", ", italic(B)[3] == 0, "  "),
                  paste(Delta == 0, ", ", italic(B)[3] == 1),
                  paste(Delta == 0.5, ", ", italic(B)[3] == 1))
legend("topright", legend=leg, lty=unlist(lty), col=unlist(colour),
    bty="n", pch=unlist(pch))
mtext("(c)", side=3, line=1, adj=0)
#dev.off()
#}}}
# figure: effect of F_MU_O; symmetric case {{{
gg.file <- "../runs/F_MU_O/gg.Rdata"
load(gg.file)

es <- (gg$C3 == 0 | gg$C3 == 1) & (gg$B3 == 0 | gg$B3 == 1)
ggs <- gg[es,]

### division of labour
#pdf(file="fig-F_MU_O-fetot.pop.size.pdf", width=7, height=6)
plot(tot.pop.size~F_MU_O, ggs, type="n", bty="l", 
    xlab=expression(paste("mortality of caring females, ",
             italic(mu[list(C,f)]))), 
    ylab="population size")
abline(h=0.5, lty=2, col="grey")
abline(v=0.2, lty=2, col="grey")
leg <- list()
lty <- list()
colour <- list()
pch <- list()
x <- unique(gg$F_MU_O)
b3 <- sort(unique(ggs$B3))
c3 <- sort(unique(ggs$C3))
for(i in 1:length(b3)) {
  for(j in 1:length(c3)) {
    es <- ggs$B3 == b3[i] & ggs$C3 == c3[j]
    y <- tapply((ggs$tot.pop.size[es]), ggs$F_MU_O[es], median)
    #y.sd <- tapply(ggs$tot.pop.size[es], ggs$F_MU_O[es], sd)
    y.iqr <- matrix(unlist(tapply((ggs$tot.pop.size[es]), ggs$F_MU_O[es],
                quantile, probs=c(0.25, 0.75))), ncol=2, byrow=TRUE)
    lines(x, y, col=j, lty=3-i, lwd=1)
    points(x, y, col=j, pch=(i-1)*15+j)
    #segments(x, y+y.sd, x, y-y.sd, col=j, lty=i)
    arrows(x, y.iqr[,1], x, y.iqr[,2], col=j, lty=3-i, length=0.05,
        angle=90, code=3)
    leg[[paste(i,j)]] <- paste("Ci=", c3[j], "B3=", b3[i])
    lty[[paste(i,j)]] <- 3-i
    colour[[paste(i,j)]] <- j
    pch[[paste(i,j)]] <- (i-1)*15+j
  }
}
leg <- expression(paste(italic(C)[3] == 0, ", ", italic(B)[3] == 0, "  "),
                  paste(italic(C)[3] == 1, ", ", italic(B)[3] == 0, "  "),
                  paste(italic(C)[3] == 0, ", ", italic(B)[3] == 1),
                  paste(italic(C)[3] == 1, ", ", italic(B)[3] == 1))
legend("topright", legend=leg, lty=unlist(lty), col=unlist(colour),
    bty="n", pch=unlist(pch))
mtext("(d)", side=3, line=1, adj=0)
#dev.off()
#}}}
layout(1)
par(op)
dev.off()
#}}}


# sandbox {{{
# figure: effect of various parameters {{{
load("../runs/RS_asymmetric/gg.Rdata")
ge <- gg[gg$B3 == 0 & gg$C12 == 1,]

pdf(file="old-figure-S5.pdf", width=8, height=5)
op <- par(mar=c(5,3,2,1)+0.1, oma=c(0,2,0,1)+0.1)
layout(matrix(1:2, ncol=2, byrow=TRUE))
## figure a: r_mating {{{
es <- ge$F_MU_O==0.2 & ge$F_MU_I==0.2 & ge$F_k_SS==1
plot(male.care~r_mating, ge, subset=es, xlim=c(0, 0.55), ylim=c(0,1),
    xlab=expression(paste("mating rate, ", italic(r[mating]))), bty="l",
    ylab="")
u <- par("usr")
qq <- tapply(ge$male.care[es], ge$r_mating[es], quantile, probs=c(0.25, 0.5,
        0.75))
qq <- matrix(unlist(qq), ncol=3)
dx <- (u[2] - u[1])/30
x <- unique(ge$r_mating[es])
segments(x-dx, qq[2,], x+dx, qq[2,], lwd=3)
lines(x, qq[2,])
mtext("(a)", side=3, adj=0, line=1)
#}}}
## figure b: F_MU_I {{{
es <- ge$F_MU_O==0.2 & ge$r_mating==0.1 & ge$F_k_SS==1
plot(I(1-male.care)~F_MU_I, ge, subset=es, ylim=c(0,1), xlim=c(0.09, 0.31),
    xlab=expression(paste("mortality of single males, ",
             italic(M[list(S,m)]))), bty="l",
    ylab="")
u <- par("usr")
qq <- tapply(1-ge$male.care[es], ge$F_MU_I[es], quantile, probs=c(0.25, 0.5,
        0.75))
qq <- matrix(unlist(qq), ncol=length(qq[[1]]), byrow=TRUE)
dx <- (u[2] - u[1])/30
x <- unique(ge$F_MU_I[es])
qq <- qq[order(x),]
x <- x[order(x)]
segments(x-dx, qq[,2], x+dx, qq[,2], lwd=3)
lines(sort(x), qq[,2])
mtext("(b)", side=3, adj=0, line=1)
#}}}
mtext("proportion of male care", side=2, adj=0.6, outer=TRUE)
layout(1)
par(op)
dev.off()

### figure c: F_k_SS {{{
#es <- ge$F_MU_O==0.2 & ge$F_MU_I==0.2 & ge$r_mating==0.1
#plot(I(1-male.care)~F_k_SS, ge, subset=es, ylim=c(0,1), xlim=c(0.8, 5.2),
#    xlab=expression(paste("level of sexual selection on males, ",
#            italic(k[m]))), bty="l",
#    ylab="")
#u <- par("usr")
#qq <- tapply(1-ge$male.care[es], ge$F_k_SS[es], quantile, probs=c(0.25, 0.5,
#        0.75))
#qq <- matrix(unlist(qq), ncol=length(qq[[1]]), byrow=TRUE)
#dx <- (u[2] - u[1])/30
#x <- unique(ge$F_k_SS[es])
#segments(x-dx, qq[,2], x+dx, qq[,2], lwd=3)
#lines(x, qq[,2])
#mtext("(c)", side=3, adj=0, line=1)
##}}}
### figure d: F_MU_O {{{
#es <- ge$F_MU_I==0.2 & ge$r_mating==0.1 & ge$F_k_SS==1
#plot(I(1-male.care)~F_MU_O, ge, subset=es, ylim=c(0,1), xlim=c(0.09, 0.31),
#    xlab=expression(paste("mortality of caring males,",
#            italic(phantom(0)[m]), italic(mu[C]))), bty="l",
#    ylab="")
#u <- par("usr")
#qq <- tapply(1-ge$male.care[es], ge$F_MU_O[es], quantile, probs=c(0.25, 0.5,
#        0.75))
#qq <- matrix(unlist(qq), ncol=length(qq[[1]]), byrow=TRUE)
#dx <- (u[2] - u[1])/30
#x <- unique(ge$F_MU_O[es])
##qq <- qq[order(x),]
#x <- x[order(x)]
#segments(x-dx, qq[,2], x+dx, qq[,2], lwd=3)
#lines(sort(x), qq[,2])
#mtext("(d)", side=3, adj=0, line=1)
##}}}
#}}}

# pop size vs cooperation {{{
# figure: effect of F_k_SS; asymmetric case {{{
gg.file <- "../runs/a-F_k_SS/gg.Rdata"
load(gg.file)

#es <- (gg$C12 == 1 | gg$C12 == 2) & (gg$B3 == 0 | gg$B3 == 1)
es <- (gg$C12 == 1 | gg$C12 == 1.5) & (gg$B3 == 0 | gg$B3 == 1)
ggs <- gg[es,]

### division of labour
#pdf(file="fig-a-F_k_SS-fetot.care.pdf", width=7, height=6)
ggs$tot.care <- ggs$E.m + ggs$E.f
plot(tot.care~F_k_SS, ggs, type="n", bty="l", 
    xlab=expression(paste("mortality of caring females, ",
             italic(mu[list(C,f)]))), 
    ylab="population size")
abline(h=0.5, lty=2, col="grey")
abline(v=0.2, lty=2, col="grey")
leg <- list()
lty <- list()
colour <- list()
pch <- list()
x <- unique(gg$F_k_SS)
b3 <- sort(unique(ggs$B3))
c3 <- sort(unique(ggs$C12))
agg <- data.frame()
for(i in 1:length(b3)) {
  for(j in 1:length(c3)) {
    print(c(i, j))
    es <- ggs$B3 == b3[i] & ggs$C12 == c3[j]
    z <- tapply((ggs$div.labour[es]), ggs$F_k_SS[es], median)
    y <- tapply((ggs$tot.care[es]), ggs$F_k_SS[es], median)
    #y.sd <- tapply(ggs$tot.care[es], ggs$F_k_SS[es], sd)
    y.iqr <- matrix(unlist(tapply((ggs$tot.care[es]), ggs$F_k_SS[es],
                quantile, probs=c(0.25, 0.75))), ncol=2, byrow=TRUE)
    yy <- cbind(unique(ggs$F_k_SS[es]), z, y)
    yy <- as.data.frame(yy)
    colnames(yy) <- c("F_k_SS", "div.labour", "pop.size")
    yy$c3 <- NA
    yy$b3 <- NA
    yy$c3 <- c3[j]
    yy$b3 <- b3[i]
    agg <- rbind(agg, yy)
    lines(x, y, col=j, lty=3-i, lwd=1)
    points(x, y, col=j, pch=(i-1)*15+j)
    #segments(x, y+y.sd, x, y-y.sd, col=j, lty=i)
    arrows(x, y.iqr[,1], x, y.iqr[,2], col=j, lty=3-i, length=0.05,
        angle=90, code=3)
    leg[[paste(i,j)]] <- paste("Ci=", c3[j], "B3=", b3[i])
    lty[[paste(i,j)]] <- 3-i
    colour[[paste(i,j)]] <- j
    pch[[paste(i,j)]] <- (i-1)*15+j
  }
}
leg <- expression(paste(Delta == 0, ", ", italic(B)[3] == 0, "  "),
                  paste(Delta == 0.5, ", ", italic(B)[3] == 0, "  "),
                  paste(Delta == 0, ", ", italic(B)[3] == 1),
                  paste(Delta == 0.5, ", ", italic(B)[3] == 1))
legend("topright", legend=leg, lty=unlist(lty), col=unlist(colour),
    bty="n", pch=unlist(pch))
mtext("(e)", side=3, line=1, adj=0)
#dev.off()
#}}}
#}}}
## robustness of results: effect of background mortality {{{
load("../runs/mortality/gg.Rdata")

syn <- paste(gg$B3, gg$C12, sep=":")
xyplot(div.labour~factor(F_k_SS)|Delta*mort, gg, group=syn,
    subset=F_MU_O == 0.2, auto.key=list(columns=6))
xyplot(div.labour~factor(F_MU_O)|Delta*mort, gg, group=syn,
    subset=F_k_SS == 1, auto.key=list(columns=6))


#}}}
## robustness of results {{{
load("../runs/RS_asymmetric/gg.Rdata")
es <- (gg$B3 == 0 & gg$C12 == 1) | (gg$B3 == 1 & gg$C12 == 2)
pdf(file="rob_asym.pdf", width=10, height=10)
xyplot(div.labour~factor(F_k_SS)|F_MU_O*F_MU_I*r_mating, gg,
    group=paste(as.character(B3), as.character(C12), sep=":"),
    subset=es, jitter.x=TRUE)
dev.off()
load("../runs/RS_symmetric/gg.Rdata")
es <- (gg$B3 == 0 & gg$C3 == 0) | (gg$B3 == 1 & gg$C3 == 1)
pdf(file="rob_sym.pdf", width=10, height=10)
xyplot(div.labour~factor(F_k_SS)|F_MU_O*F_MU_I*r_mating, gg,
    group=paste(as.character(B3), as.character(C3), sep=":"),
    subset=es, jitter.x=TRUE)
dev.off()
#}}}
## benefits of role specialisation {{{

gg.file <- "../runs/a-F_k_SS/gg.Rdata"
load(gg.file)

es <- gg$F_k_SS == 5
ggs <- gg[es,]
ggs <- gg

layout(matrix(1:2, ncol=2))
plot(tot.pop.size~div.labour, ggs)
plot(I(E.f+E.m)~div.labour, ggs)
layout(1)

layout(matrix(1:2, ncol=2))
plot(tot.pop.size~role.spec, ggs)
plot(I(E.f+E.m)~role.spec, ggs)
layout(1)

xyplot(tot.pop.size~B3|C12, ggs)



dl <- cut(ggs$div.labour, breaks=seq(0,1,0.1))
layout(matrix(1:2, ncol=2))
plot(tot.pop.size~dl, ggs, varwidth=TRUE, outline=FALSE)
plot(I(E.f+E.m)~dl, ggs, varwidth=TRUE, outline=FALSE)
layout(1)


dev.set(dev.next())
gg.file <- "../runs/F_k_SS/gg.Rdata"
load(gg.file)

es <- gg$F_k_SS == 1
ggs <- gg[es,]
ggs <- gg

layout(matrix(1:2, ncol=2))
plot(tot.pop.size~div.labour, ggs)
plot(I(E.f+E.m)~div.labour, ggs)
layout(1)

dl <- cut(ggs$div.labour, breaks=seq(0,1,0.1))
layout(matrix(1:2, ncol=2))
plot(tot.pop.size~dl, ggs, varwidth=TRUE, outline=FALSE)
plot(I(E.f+E.m)~dl, ggs, varwidth=TRUE, outline=FALSE)
layout(1)


#}}}
## role specialisation vs division of labour {{{
library(rgl)
go <- data.frame()
dirs <- c("a-F_MU_O", "a-F_k_SS", "F_MU_O", "F_k_SS")
START <- TRUE
for(d in dirs) {
  f <- paste("../runs", d, "gg.Rdata", sep="/")
  print(f)
  load(f)
  print(nrow(gg))
  print(gg$ID[1])
  if(sum(grepl("C12", names(gg))) == 1) {
    gg$C12 <- gg$C12 - 1
    gg$type <- "skill diff."
  } else {
    gg$type <- "int. cost"
  }
  if(START) n <- names(gg)
  START <- FALSE
  names(gg) <- n
  if(grepl("_k_", d)) {
    es <- gg$F_k_SS > 5 & gg$F_k_SS < 10
  } else {
    es <- gg$F_MU_O == 0.18 || gg$F_MU_O == 0.22
  }
  go <- rbind(go, gg[es,])
}




dv <- cut(go$div.labour, breaks=seq(0,1, 0.1))
rs <- cut(go$role.spec, breaks=seq(0,1, 0.1))
table(dv, rs)
#xyplot(div.labour~role.spec|B3*C12, go)

open3d()
rgl.viewpoint(theta=-50, phi=30, fov=10, zoom=1, scale=c(1,0.7,1))
# to use hist3d first run demo(hist3d). it seems hist3d defined here
hist3d(go$role.spec, go$div.labour, nclass=10)
rgl.light(45, 45, 45)
axes3d(c("x-+", "y", "z--"))
#mtext3d("frequency", edge="y--", line=0)
mtext3d("role specialisation", edge="x-+", line=2.5)
mtext3d("division of labour", edge="z--", line=2.5)
mtext3d("frequency [x 1000]", edge="x", pos=c(NA, 1.7, -0.5))
rgl.clear()
rgl.close()
# the size of the pdf fig depends on the size of the graph on the
# screen!!!
rgl.postscript("fig-freq.pdf", fmt="pdf")
#}}}
#}}}

# vim: foldmethod=marker
