
## data processing for the role specialisation project

setwd("../work")

O.series <- function(pattern, path=".", reader=O.gen) {#{{{
  ## read a series of data files

  #pattern <- sub("$", ".*\\.dat", pattern)
  f.l <- list.files(pattern=pattern, path=path, full.names=TRUE)
  #f.l <- sub("\\.dat$", "", f.l)
  r <- data.frame()
  for(f in f.l) {
    x <- reader(f)
    r <- rbind(r, x)
  }
  invisible(r)
}#}}}

O.gen <- function(f.name, gzipped=TRUE) {#{{{
  # load the population mean data over the generations
  # f.name -> the file contains the data
  # gzipped -> is the file gzipped?
  if (gzipped) gr <- "zgrep" else gr <- "grep"
  r <- read.table(file=pipe(paste(gr, "^M", f.name)),
      col.names=c("M", "gen", "sex", "pop.size", "mort", "T1.m", "T1.f",
          "T2.m", "T2.f", "age", "n.eggs"))
  r$M <- NULL
  r$sex <- factor(r$sex, labels=c("male", "female"))
  r$status <- rep(c("single", "single", "paired", "paired"),
      length.out=nrow(r))
  r$ID <- f.name
  invisible(r)
}#}}}

O.pop <- function(nev) { #{{{
  r <- read.table(file=pipe(paste("zgrep '^[0-9]' ", nev)))
  names(r) <- c("mort", "T1M", "T1F", "T2M", "T2F", "n.eggs", "age", "sex")
  if(length(unique(r$age)) == 2) {
    r$age <- factor(r$age, labels=c("ad", "juv"))
  } else if(unique(r$age) == "J") {
    r$age <- factor(r$age, labels=c("juv")) 
  } else {
    r$age <- factor(r$age, labels=c("ad")) 
  }
  if(length(unique(r$sex)) == 2) {
    r$sex <- factor(r$sex, labels=c("female", "male"))
  } else if(unique(r$sex) == "M") {
    r$sex <- factor(r$sex, labels=c("male")) 
  } else {
    r$sex <- factor(r$sex, labels=c("female")) 
  }
  r$ID <- nev
  invisible(r)
}#}}}

P.pop <- function(nev) {#{{{
  g <- O.gen.short(nev, 32)
  # process the population data, calculate several derived messures
  es <- g$pop.size > 0
  sps <- sum(g$pop.size[es])
  E.m <- sum(g$pop.size[es]*g$T1.m[es])/sps
  E.f <- sum(g$pop.size[es]*g$T1.f[es])/sps
  A.m <- sum(g$pop.size[es]*g$T2.m[es])/sps
  A.f <- sum(g$pop.size[es]*g$T2.f[es])/sps
  r <- data.frame(E.m=E.m, E.f=E.f, A.m=A.m, A.f=A.f)
  ps <- tapply(g$pop.size, g$gen, sum)
  r$tot.pop.size <- mean(ps)
  i <- rep(1:4, length.out=nrow(g))
  r$single.m <- mean(g$pop.size[i==1])
  r$single.f <- mean(g$pop.size[i==2])
  r$paired.m <- mean(g$pop.size[i==3])
  r$paired.f <- mean(g$pop.size[i==4])
  r$div.labour <- div.labour(E.m, E.f)
  r$role.spec <- role.spec(A.m, A.f)
  r$sex.ratio.t <- sex.ratio(r$single.m+r$paired.m,
      r$single.f+r$paired.f)
  r$sex.ratio.s <- sex.ratio(r$single.m, r$single.f)
  r$sex.ratio.p <- sex.ratio(r$paired.m, r$paired.f)
  r$ID <- nev
  r
}#}}}

P.pop.old <- function(r) {#{{{
  m.T <- colMeans(r[,c("mort", "T1M", "T1F", "T2M", "T2F")])
  m.sa <- n.sa <- numeric(4)
  names(m.sa) <- names(n.sa) <- c("juv.male", "juv.female", "ad.male",
      "ad.female")
  n <- table(r$sex, r$age)
  m <- tapply(r$mort, list(r$sex, r$age), mean)
  nn <- t(outer(colnames(n), rownames(n), paste, sep="."))
  n <- as.vector(n)
  m <- as.vector(m)
  names(n) <- as.vector(nn)
  names(m) <- as.vector(nn)
  n.sa[names(n)] <- n
  m.sa[names(m)] <- m
  names(m.sa) <- paste("m", names(m.sa), sep=".")
  m <- c(pop.size=nrow(r), n.sa, m.sa, m.T)
  m
}#}}}

O.gen.short <- function(f.name, n.lines=32, gzipped=TRUE) {#{{{
  # load the population mean data over the generations
  # f.name -> the file contains the data
  # n.lines -> only the last n.lines number of lines read
  # gzipped -> is the file gzipped?
  if (gzipped) gr <- "zgrep" else gr <- "grep"
  r <- read.table(file=pipe(paste(gr, " ^M ", f.name, "|tail -",
              n.lines, sep="")),
      col.names=c("M", "gen", "sex", "pop.size", "mort", "T1.m", "T1.f",
          "T2.m", "T2.f", "age", "n.eggs"))
  r$M <- NULL
  r$ID <- f.name
  r$sex <- factor(r$sex, labels=c("male", "female"))
  invisible(r)
}#}}}

division <- function(s) {#{{{
  # calculates the division of parental effort between the two parents
  # s -> the data.frame containing the efforts
  a <- (s$T1.m + s$T2.m) / (s$T1.m + s$T1.f + s$T2.m + s$T2.f)
  1 - abs(a - 0.5)*2
}#}}}
role.spec.old <- function(s) {#{{{
  # calculates the role specialisation of parental effort between the
  # two parents
  # s -> the data.frame containing the efforts
  (s$T1.m - s$T2.m)/(s$T1.m + s$T2.m) * (s$T1.f - s$T2.f)/(s$T1.f +
      s$T2.f)
}#}}}
tot.effort <- function(s) {#{{{
  # calculates the total parental effort invested
  # s -> the data.frame containing the efforts
  s$T1.m + s$T1.f + s$T2.m + s$T2.f
}#}}}

pl.tasks <- function(r) {#{{{
  layout(matrix(1:2, ncol=2))
  plot(T1.m~gen, r, subset=sex=="female", ylim=c(0,1.1), type="l",
      main="Females")
  lines(T1.f~gen, r, col=2, subset=sex=="female")
  lines(T2.m~gen, r, col=3, subset=sex=="female")
  lines(T2.f~gen, r, col=4, subset=sex=="female")
  legend("top", legend=c("T1 male", "T1 female", "T2 male", 
          "T2 female"), ncol=4, bty="n", lty=1, col=1:4)
  plot(T1.m~gen, r, subset=sex=="male", ylim=c(0,1.1), type="l",
      main="Males")
  lines(T1.f~gen, r, col=2, subset=sex=="male")
  lines(T2.m~gen, r, col=3, subset=sex=="male")
  lines(T2.f~gen, r, col=4, subset=sex=="male")
  legend("top", legend=c("T1 male", "T1 female", "T2 male", 
          "T2 female"), ncol=4, bty="n", lty=1, col=1:4)
  layout(1)
}#}}}

pl.gen <- function(r, max.care=25) {#{{{
  layout(matrix(1:4, ncol=2))
  opar <- par(mar=c(4,4,3,1)+0.1)
  plot(T1.m~gen, r, ylim=c(0,max(r$T1.m, r$T1.f, na.rm=TRUE)), type="l",
      xlab="generation", ylab="parental investment", 
      main="division of labour")
  lines(T1.f~gen, r, col=2)
  legend("top", legend=c("male", "female"), ncol=2, bty="n", lty=1, col=1:2)
  plot(T2.m~gen, r, ylim=c(0,1.1), type="l",
      xlab="generation", ylab="investment in task 1", 
      main="role specialisation")
  lines(T2.f~gen, r, col=2)
  legend("top", legend=c("male", "female"), ncol=2, bty="n", lty=1, col=1:2)
  r <- r[r$gen >= 0,]
  plot(pop.size~gen, r, subset=sex=="male" & status=="single", type="l",
      ylim=c(0, 1.1*max(pop.size, na.rm=TRUE)), xlab="generation",
      ylab="population size", main="population size")
  lines(pop.size~gen, r, subset=sex=="male" & status=="paired", lty=2)
  lines(pop.size~gen, r, subset=sex=="female" & status=="single", lty=1,
      col=2)
  lines(pop.size~gen, r, subset=sex=="female" & status=="paired", lty=2,
      col=2)
  legend("top", legend=c("male single", "male paired", "female single",
          "female paired"), ncol=4, bty="n", lty=c(1,2,1,2),
      col=c(1,1,2,2))
  dl <- div.labour(r$T1.m, r$T1.f)
  rs <- role.spec(r$T2.m, r$T2.f)
  plot(dl~r$gen, type="l", xlab="generation", ylim=c(0,1))
  lines(rs~r$gen, col=2)
  pm <- tapply(r$pop.size, list(r$gen, r$sex), sum, na.rm=TRUE)
  sr.tot <- sex.ratio(pm[,"male"], pm[,"female"])
  lines(sr.tot~as.numeric(rownames(pm)), col=3)
  sr.single <- sex.ratio(r$pop.size[r$sex=="male" & r$status=="single"],
      r$pop.size[r$sex=="female" & r$status=="single"])
  lines(sr.single~r$gen[r$sex=="male" & r$status=="single"], col=4)
  sr.paired <- sex.ratio(r$pop.size[r$sex=="male" & r$status=="paired"],
      r$pop.size[r$sex=="female" & r$status=="paired"])
  lines(sr.single~r$gen[r$sex=="male" & r$status=="paired"], col=5)
  grid()
  par(opar)
  layout(1)
}#}}}

role.sp.R <- function(Es) {#{{{
  # calculation of specialisation according to Petraitis W_i (Bolnick et
  # al 2002
  Es <- c(Es[1], 1-Es[1], Es[2], 1-Es[2])
  m <- matrix(Es, ncol=2)
  Q <- colSums(m)/sum(m)
  P <- t(apply(m, 1, function(z) z/sum(z)))
  la <- sapply(1:nrow(m), function(z) {
          prod((Q/P[z,])^m[z,])
        })
  Wi <- la^(1/rowSums(m))
  mean(Wi)/0.5 - 1
} #}}}

role.spec <- function(E1.m, E1.f) {#{{{
  # role specialisation index
  rs <- abs((E1.m - E1.f)/(E1.m + E1.f))
  #rs.m <- abs(2*E1.m - 1)
  #rs.f <- abs(2*E1.f - 1)
  #c(rs=rs, rs.m=rs.m, rs.f=rs.f)
  rs
}#}}}

div.labour <- function(m, f) {#{{{
  1 - abs((m-f)/(m+f))
}#}}}

sex.ratio <- function(m, f) {#{{{
  m/(m+f)
}#}}}

# vim: set foldmethod=marker:
